#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .adaptive_time_stepping import adaptive_time_stepping
from .cfl_based_adaptive_time_stepping import cfl_based_adaptive_time_stepping
from .data_sampling_1 import data_sampling
from .transient_controls import transient_controls
from .dual_time_iterate import dual_time_iterate
from .iterate import iterate
class run_calculation(Group):
    """
    'run_calculation' child.
    """

    fluent_name = "run-calculation"

    child_names = \
        ['adaptive_time_stepping', 'cfl_based_adaptive_time_stepping',
         'data_sampling', 'transient_controls']

    adaptive_time_stepping: adaptive_time_stepping = adaptive_time_stepping
    """
    adaptive_time_stepping child of run_calculation.
    """
    cfl_based_adaptive_time_stepping: cfl_based_adaptive_time_stepping = cfl_based_adaptive_time_stepping
    """
    cfl_based_adaptive_time_stepping child of run_calculation.
    """
    data_sampling: data_sampling = data_sampling
    """
    data_sampling child of run_calculation.
    """
    transient_controls: transient_controls = transient_controls
    """
    transient_controls child of run_calculation.
    """
    command_names = \
        ['dual_time_iterate', 'iterate']

    dual_time_iterate: dual_time_iterate = dual_time_iterate
    """
    dual_time_iterate command of run_calculation.
    """
    iterate: iterate = iterate
    """
    iterate command of run_calculation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .diffusion_collision_integral import diffusion_collision_integral
from .viscosity_collision_integral import viscosity_collision_integral
class neutral_involved_interaction(Group):
    """
    'neutral_involved_interaction' child.
    """

    fluent_name = "neutral-involved-interaction"

    child_names = \
        ['diffusion_collision_integral', 'viscosity_collision_integral']

    diffusion_collision_integral: diffusion_collision_integral = diffusion_collision_integral
    """
    diffusion_collision_integral child of neutral_involved_interaction.
    """
    viscosity_collision_integral: viscosity_collision_integral = viscosity_collision_integral
    """
    viscosity_collision_integral child of neutral_involved_interaction.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class last_view(Command):
    """
    Return to the camera position before the last manipulation.
    """

    fluent_name = "last-view"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .file_path import file_path
class write_simulation_report_names_to_file(Command):
    """
    Write the list of currently generated report names to a txt file.
    
    Parameters
    ----------
        file_path : str
            'file_path' child.
    
    """

    fluent_name = "write-simulation-report-names-to-file"

    argument_names = \
        ['file_path']

    file_path: file_path = file_path
    """
    file_path argument of write_simulation_report_names_to_file.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .pressure_corr_grad import pressure_corr_grad
from .face_pressure_calculation_method import face_pressure_calculation_method
from .exclude_transient_term_in_face_pressure_calc import exclude_transient_term_in_face_pressure_calc
class face_pressure_options(Group):
    """
    'face_pressure_options' child.
    """

    fluent_name = "face-pressure-options"

    child_names = \
        ['pressure_corr_grad', 'face_pressure_calculation_method',
         'exclude_transient_term_in_face_pressure_calc']

    pressure_corr_grad: pressure_corr_grad = pressure_corr_grad
    """
    pressure_corr_grad child of face_pressure_options.
    """
    face_pressure_calculation_method: face_pressure_calculation_method = face_pressure_calculation_method
    """
    face_pressure_calculation_method child of face_pressure_options.
    """
    exclude_transient_term_in_face_pressure_calc: exclude_transient_term_in_face_pressure_calc = exclude_transient_term_in_face_pressure_calc
    """
    exclude_transient_term_in_face_pressure_calc child of face_pressure_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .smoothing_iteration import smoothing_iteration
class smooth_partition(Command):
    """
    Smooth partition interface.
    
    Parameters
    ----------
        smoothing_iteration : int
            Set maximum number of smoothing iterations.
    
    """

    fluent_name = "smooth-partition"

    argument_names = \
        ['smoothing_iteration']

    smoothing_iteration: smoothing_iteration = smoothing_iteration
    """
    smoothing_iteration argument of smooth_partition.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class set_solution_methods_to_default(Command):
    """
    'set_solution_methods_to_default' command.
    """

    fluent_name = "set-solution-methods-to-default"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .half_angle import half_angle
from .dispersion_angle import dispersion_angle
from .inner_radius import inner_radius
from .outer_radius import outer_radius
from .x_axis import x_axis
from .y_axis import y_axis
from .z_axis import z_axis
class cone_settings(Group):
    """
    'cone_settings' child.
    """

    fluent_name = "cone-settings"

    child_names = \
        ['half_angle', 'dispersion_angle', 'inner_radius', 'outer_radius',
         'x_axis', 'y_axis', 'z_axis']

    half_angle: half_angle = half_angle
    """
    half_angle child of cone_settings.
    """
    dispersion_angle: dispersion_angle = dispersion_angle
    """
    dispersion_angle child of cone_settings.
    """
    inner_radius: inner_radius = inner_radius
    """
    inner_radius child of cone_settings.
    """
    outer_radius: outer_radius = outer_radius
    """
    outer_radius child of cone_settings.
    """
    x_axis: x_axis = x_axis
    """
    x_axis child of cone_settings.
    """
    y_axis: y_axis = y_axis
    """
    y_axis child of cone_settings.
    """
    z_axis: z_axis = z_axis
    """
    z_axis child of cone_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .roughness_correlation import roughness_correlation
class transition_sst_options(Group):
    """
    'transition_sst_options' child.
    """

    fluent_name = "transition-sst-options"

    child_names = \
        ['roughness_correlation']

    roughness_correlation: roughness_correlation = roughness_correlation
    """
    roughness_correlation child of transition_sst_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class automatic_skip(Boolean):
    """
    Determine whether to skip labels in the colopmap scale automatically.
    """

    fluent_name = "automatic-skip?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .counter_clockwise import counter_clockwise
class roll(Command):
    """
    Adjust the camera up-vector.
    
    Parameters
    ----------
        counter_clockwise : real
            'counter_clockwise' child.
    
    """

    fluent_name = "roll"

    argument_names = \
        ['counter_clockwise']

    counter_clockwise: counter_clockwise = counter_clockwise
    """
    counter_clockwise argument of roll.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class load_case_data(Command):
    """
    Loads relevant case/data file for current design point.
    """

    fluent_name = "load-case-data"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .model import model
from .options import options
from .spalart_allmaras_production import spalart_allmaras_production
from .k_epsilon_model import k_epsilon_model
from .k_omega_model import k_omega_model
from .k_omega_options import k_omega_options
from .rng_options import rng_options
from .near_wall_treatment import near_wall_treatment
from .transition_sst_options import transition_sst_options
from .reynolds_stress_model import reynolds_stress_model
from .subgrid_scale_model import subgrid_scale_model
from .les_model_options import les_model_options
from .reynolds_stress_options import reynolds_stress_options
from .enhanced_wall_treatment_options import enhanced_wall_treatment_options
from .rans_model import rans_model
class viscous(Group):
    """
    'viscous' child.
    """

    fluent_name = "viscous"

    child_names = \
        ['model', 'options', 'spalart_allmaras_production', 'k_epsilon_model',
         'k_omega_model', 'k_omega_options', 'rng_options',
         'near_wall_treatment', 'transition_sst_options',
         'reynolds_stress_model', 'subgrid_scale_model', 'les_model_options',
         'reynolds_stress_options', 'enhanced_wall_treatment_options',
         'rans_model']

    model: model = model
    """
    model child of viscous.
    """
    options: options = options
    """
    options child of viscous.
    """
    spalart_allmaras_production: spalart_allmaras_production = spalart_allmaras_production
    """
    spalart_allmaras_production child of viscous.
    """
    k_epsilon_model: k_epsilon_model = k_epsilon_model
    """
    k_epsilon_model child of viscous.
    """
    k_omega_model: k_omega_model = k_omega_model
    """
    k_omega_model child of viscous.
    """
    k_omega_options: k_omega_options = k_omega_options
    """
    k_omega_options child of viscous.
    """
    rng_options: rng_options = rng_options
    """
    rng_options child of viscous.
    """
    near_wall_treatment: near_wall_treatment = near_wall_treatment
    """
    near_wall_treatment child of viscous.
    """
    transition_sst_options: transition_sst_options = transition_sst_options
    """
    transition_sst_options child of viscous.
    """
    reynolds_stress_model: reynolds_stress_model = reynolds_stress_model
    """
    reynolds_stress_model child of viscous.
    """
    subgrid_scale_model: subgrid_scale_model = subgrid_scale_model
    """
    subgrid_scale_model child of viscous.
    """
    les_model_options: les_model_options = les_model_options
    """
    les_model_options child of viscous.
    """
    reynolds_stress_options: reynolds_stress_options = reynolds_stress_options
    """
    reynolds_stress_options child of viscous.
    """
    enhanced_wall_treatment_options: enhanced_wall_treatment_options = enhanced_wall_treatment_options
    """
    enhanced_wall_treatment_options child of viscous.
    """
    rans_model: rans_model = rans_model
    """
    rans_model child of viscous.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .x_axis_function import x_axis_function
from .enabled_2 import enabled
class plot(Group):
    """
    'plot' child.
    """

    fluent_name = "plot"

    child_names = \
        ['x_axis_function', 'enabled']

    x_axis_function: x_axis_function = x_axis_function
    """
    x_axis_function child of plot.
    """
    enabled: enabled = enabled
    """
    enabled child of plot.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .fixed_cycle_parameters_2 import fixed_cycle_parameters
from .coarsening_parameters_2 import coarsening_parameters
from .relaxation_factor import relaxation_factor
from .options_1 import options
class fas_mg_controls(Group):
    """
    'fas_mg_controls' child.
    """

    fluent_name = "fas-mg-controls"

    child_names = \
        ['fixed_cycle_parameters', 'coarsening_parameters',
         'relaxation_factor', 'options']

    fixed_cycle_parameters: fixed_cycle_parameters = fixed_cycle_parameters
    """
    fixed_cycle_parameters child of fas_mg_controls.
    """
    coarsening_parameters: coarsening_parameters = coarsening_parameters
    """
    coarsening_parameters child of fas_mg_controls.
    """
    relaxation_factor: relaxation_factor = relaxation_factor
    """
    relaxation_factor child of fas_mg_controls.
    """
    options: options = options
    """
    options child of fas_mg_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .set_filetype import set_filetype
class set_cgns_export_filetype(Command):
    """
    Select HDF5 or ADF as file format for CGNS.
    
    Parameters
    ----------
        set_filetype : bool
            'set_filetype' child.
    
    """

    fluent_name = "set-cgns-export-filetype"

    argument_names = \
        ['set_filetype']

    set_filetype: set_filetype = set_filetype
    """
    set_filetype argument of set_cgns_export_filetype.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name_1 import name
from .uid import uid
from .options_10 import options
from .plot_direction import plot_direction
from .x_axis_function import x_axis_function
from .y_axis_function import y_axis_function
from .surfaces_list import surfaces_list
from .physics import physics
from .geometry_3 import geometry
from .surfaces import surfaces
from .axes import axes
from .curves import curves
from .display_2 import display
class xy_plot_child(Group):
    """
    'child_object_type' of xy_plot.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'uid', 'options', 'plot_direction', 'x_axis_function',
         'y_axis_function', 'surfaces_list', 'physics', 'geometry',
         'surfaces', 'axes', 'curves']

    name: name = name
    """
    name child of xy_plot_child.
    """
    uid: uid = uid
    """
    uid child of xy_plot_child.
    """
    options: options = options
    """
    options child of xy_plot_child.
    """
    plot_direction: plot_direction = plot_direction
    """
    plot_direction child of xy_plot_child.
    """
    x_axis_function: x_axis_function = x_axis_function
    """
    x_axis_function child of xy_plot_child.
    """
    y_axis_function: y_axis_function = y_axis_function
    """
    y_axis_function child of xy_plot_child.
    """
    surfaces_list: surfaces_list = surfaces_list
    """
    surfaces_list child of xy_plot_child.
    """
    physics: physics = physics
    """
    physics child of xy_plot_child.
    """
    geometry: geometry = geometry
    """
    geometry child of xy_plot_child.
    """
    surfaces: surfaces = surfaces
    """
    surfaces child of xy_plot_child.
    """
    axes: axes = axes
    """
    axes child of xy_plot_child.
    """
    curves: curves = curves
    """
    curves child of xy_plot_child.
    """
    command_names = \
        ['display']

    display: display = display
    """
    display command of xy_plot_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#
# pylint: disable=line-too-long

from ansys.fluent.core.services.datamodel_se import (
    PyMenu,
    PyParameter,
    PyTextual,
    PyNumerical,
    PyDictionary,
    PyNamedObjectContainer,
    PyCommand
)


class Root(PyMenu):
    """
    Singleton Root.
    """
    def __init__(self, service, rules, path):
        self.File = self.__class__.File(service, rules, path + [("File", "")])
        self.FileManager = self.__class__.FileManager(service, rules, path + [("FileManager", "")])
        super().__init__(service, rules, path)

    class File(PyNamedObjectContainer):
        """
        .
        """
        class _File(PyMenu):
            """
            Singleton _File.
            """
            def __init__(self, service, rules, path):
                self.Options = self.__class__.Options(service, rules, path + [("Options", "")])
                self.Append = self.__class__.Append(service, rules, path + [("Append", "")])
                self.ConvertedPath = self.__class__.ConvertedPath(service, rules, path + [("ConvertedPath", "")])
                self.Dummy = self.__class__.Dummy(service, rules, path + [("Dummy", "")])
                self.FileUnit = self.__class__.FileUnit(service, rules, path + [("FileUnit", "")])
                self.IgnoreSolidNames = self.__class__.IgnoreSolidNames(service, rules, path + [("IgnoreSolidNames", "")])
                self.JtLOD = self.__class__.JtLOD(service, rules, path + [("JtLOD", "")])
                self.Keys = self.__class__.Keys(service, rules, path + [("Keys", "")])
                self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
                self.PartPerBody = self.__class__.PartPerBody(service, rules, path + [("PartPerBody", "")])
                self.Path = self.__class__.Path(service, rules, path + [("Path", "")])
                self.Route = self.__class__.Route(service, rules, path + [("Route", "")])
                self.Updated = self.__class__.Updated(service, rules, path + [("Updated", "")])
                self._name_ = self.__class__._name_(service, rules, path + [("_name_", "")])
                super().__init__(service, rules, path)

            class Options(PyMenu):
                """
                Singleton Options.
                """
                def __init__(self, service, rules, path):
                    self.Line = self.__class__.Line(service, rules, path + [("Line", "")])
                    self.Solid = self.__class__.Solid(service, rules, path + [("Solid", "")])
                    self.Surface = self.__class__.Surface(service, rules, path + [("Surface", "")])
                    super().__init__(service, rules, path)

                class Line(PyParameter):
                    """
                    Parameter Line of value type bool.
                    """
                    pass

                class Solid(PyParameter):
                    """
                    Parameter Solid of value type bool.
                    """
                    pass

                class Surface(PyParameter):
                    """
                    Parameter Surface of value type bool.
                    """
                    pass

            class Append(PyParameter):
                """
                Parameter Append of value type bool.
                """
                pass

            class ConvertedPath(PyTextual):
                """
                Parameter ConvertedPath of value type str.
                """
                pass

            class Dummy(PyParameter):
                """
                Parameter Dummy of value type bool.
                """
                pass

            class FileUnit(PyTextual):
                """
                Parameter FileUnit of value type str.
                """
                pass

            class IgnoreSolidNames(PyParameter):
                """
                Parameter IgnoreSolidNames of value type bool.
                """
                pass

            class JtLOD(PyTextual):
                """
                Parameter JtLOD of value type str.
                """
                pass

            class Keys(PyParameter):
                """
                Parameter Keys of value type List[int].
                """
                pass

            class Name(PyTextual):
                """
                Parameter Name of value type str.
                """
                pass

            class PartPerBody(PyParameter):
                """
                Parameter PartPerBody of value type bool.
                """
                pass

            class Path(PyTextual):
                """
                Parameter Path of value type str.
                """
                pass

            class Route(PyTextual):
                """
                Parameter Route of value type str.
                """
                pass

            class Updated(PyParameter):
                """
                Parameter Updated of value type bool.
                """
                pass

            class _name_(PyTextual):
                """
                Parameter _name_ of value type str.
                """
                pass

        def __getitem__(self, key: str) -> _File:
            return super().__getitem__(key)

    class FileManager(PyMenu):
        """
        Singleton FileManager.
        """
        def __init__(self, service, rules, path):
            self.Children = self.__class__.Children(service, rules, path + [("Children", "")])
            self.Name = self.__class__.Name(service, rules, path + [("Name", "")])
            self.DeleteCadKey = self.__class__.DeleteCadKey(service, rules, "DeleteCadKey", path)
            self.LoadFiles = self.__class__.LoadFiles(service, rules, "LoadFiles", path)
            self.Reload = self.__class__.Reload(service, rules, "Reload", path)
            self.Unload = self.__class__.Unload(service, rules, "Unload", path)
            super().__init__(service, rules, path)

        class Children(PyTextual):
            """
            Parameter Children of value type List[str].
            """
            pass

        class Name(PyTextual):
            """
            Parameter Name of value type str.
            """
            pass

        class DeleteCadKey(PyCommand):
            """
            Command DeleteCadKey.

            Parameters
            ----------
            Key : int

            Returns
            -------
            bool
            """
            pass

        class LoadFiles(PyCommand):
            """
            Command LoadFiles.


            Returns
            -------
            bool
            """
            pass

        class Reload(PyCommand):
            """
            Command Reload.

            Parameters
            ----------
            FileName : str

            Returns
            -------
            bool
            """
            pass

        class Unload(PyCommand):
            """
            Command Unload.

            Parameters
            ----------
            FileName : str

            Returns
            -------
            bool
            """
            pass




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .right import right
from .up import up
from .in_ import in_
class dolly(Command):
    """
    Adjust the camera position and target.
    
    Parameters
    ----------
        right : real
            'right' child.
        up : real
            'up' child.
        in_ : real
            'in' child.
    
    """

    fluent_name = "dolly"

    argument_names = \
        ['right', 'up', 'in_']

    right: right = right
    """
    right argument of dolly.
    """
    up: up = up
    """
    up argument of dolly.
    """
    in_: in_ = in_
    """
    in_ argument of dolly.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class track_in_absolute_frame(Boolean):
    """
    Enable/disable tracking of particles in the absolute frame. Please note that tracking in the relative frame is the recommended default.
    """

    fluent_name = "track-in-absolute-frame?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable_prod_limiter import enable_prod_limiter
from .clip_factor import clip_factor
class production_limiter(Group):
    """
    'production_limiter' child.
    """

    fluent_name = "production-limiter"

    child_names = \
        ['enable_prod_limiter', 'clip_factor']

    enable_prod_limiter: enable_prod_limiter = enable_prod_limiter
    """
    enable_prod_limiter child of production_limiter.
    """
    clip_factor: clip_factor = clip_factor
    """
    clip_factor child of production_limiter.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class sample_file(Filename):
    """
    Enter the name of a sample file to be loaded.
    """

    fluent_name = "sample-file"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .phase_11 import phase
from .thermal_bc import thermal_bc
from .temperature import temperature
from .q import q
class network_end_child(Group):
    """
    'child_object_type' of network_end.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'thermal_bc', 'temperature', 'q']

    phase: phase = phase
    """
    phase child of network_end_child.
    """
    thermal_bc: thermal_bc = thermal_bc
    """
    thermal_bc child of network_end_child.
    """
    temperature: temperature = temperature
    """
    temperature child of network_end_child.
    """
    q: q = q
    """
    q child of network_end_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .force_child import force_child

class force(NamedObject[force_child], _CreatableNamedObjectMixin[force_child]):
    """
    'force' child.
    """

    fluent_name = "force"

    child_object_type: force_child = force_child
    """
    child_object_type of force.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .execute_commands import execute_commands
from .solution_animations import solution_animations
from .poor_mesh_numerics import poor_mesh_numerics
from .enable_strategy import enable_strategy
from .copy_modification import copy_modification
from .delete_modification import delete_modification
from .enable_modification import enable_modification
from .disable_modification import disable_modification
from .import_modifications import import_modifications
from .export_modifications import export_modifications
from .continue_strategy_execution import continue_strategy_execution
class calculation_activity(Group):
    """
    'calculation_activity' child.
    """

    fluent_name = "calculation-activity"

    child_names = \
        ['execute_commands', 'solution_animations', 'poor_mesh_numerics']

    execute_commands: execute_commands = execute_commands
    """
    execute_commands child of calculation_activity.
    """
    solution_animations: solution_animations = solution_animations
    """
    solution_animations child of calculation_activity.
    """
    poor_mesh_numerics: poor_mesh_numerics = poor_mesh_numerics
    """
    poor_mesh_numerics child of calculation_activity.
    """
    command_names = \
        ['enable_strategy', 'copy_modification', 'delete_modification',
         'enable_modification', 'disable_modification',
         'import_modifications', 'export_modifications',
         'continue_strategy_execution']

    enable_strategy: enable_strategy = enable_strategy
    """
    enable_strategy command of calculation_activity.
    """
    copy_modification: copy_modification = copy_modification
    """
    copy_modification command of calculation_activity.
    """
    delete_modification: delete_modification = delete_modification
    """
    delete_modification command of calculation_activity.
    """
    enable_modification: enable_modification = enable_modification
    """
    enable_modification command of calculation_activity.
    """
    disable_modification: disable_modification = disable_modification
    """
    disable_modification command of calculation_activity.
    """
    import_modifications: import_modifications = import_modifications
    """
    import_modifications command of calculation_activity.
    """
    export_modifications: export_modifications = export_modifications
    """
    export_modifications command of calculation_activity.
    """
    continue_strategy_execution: continue_strategy_execution = continue_strategy_execution
    """
    continue_strategy_execution command of calculation_activity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .angle import angle
from .origin import origin
from .axis_components import axis_components
class rotate(Command):
    """
    Rotate the mesh.
    
    Parameters
    ----------
        angle : real
            'angle' child.
        origin : typing.Tuple[real, real, real]
            'origin' child.
        axis_components : typing.Tuple[real, real, real]
            'axis_components' child.
    
    """

    fluent_name = "rotate"

    argument_names = \
        ['angle', 'origin', 'axis_components']

    angle: angle = angle
    """
    angle argument of rotate.
    """
    origin: origin = origin
    """
    origin argument of rotate.
    """
    axis_components: axis_components = axis_components
    """
    axis_components argument of rotate.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .child_object_type_child import child_object_type_child

class flux_momentum_components(ListObject[child_object_type_child]):
    """
    'flux_momentum_components' child.
    """

    fluent_name = "flux-momentum-components"

    child_object_type: child_object_type_child = child_object_type_child
    """
    child_object_type of flux_momentum_components.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .cavitation import cavitation
from .evaporation_condensation import evaporation_condensation
from .boiling import boiling
from .area_density_1 import area_density
from .alternative_energy_treatment import alternative_energy_treatment
class heat_mass_transfer(Group):
    """
    'heat_mass_transfer' child.
    """

    fluent_name = "heat-mass-transfer"

    child_names = \
        ['cavitation', 'evaporation_condensation', 'boiling', 'area_density',
         'alternative_energy_treatment']

    cavitation: cavitation = cavitation
    """
    cavitation child of heat_mass_transfer.
    """
    evaporation_condensation: evaporation_condensation = evaporation_condensation
    """
    evaporation_condensation child of heat_mass_transfer.
    """
    boiling: boiling = boiling
    """
    boiling child of heat_mass_transfer.
    """
    area_density: area_density = area_density
    """
    area_density child of heat_mass_transfer.
    """
    alternative_energy_treatment: alternative_energy_treatment = alternative_energy_treatment
    """
    alternative_energy_treatment child of heat_mass_transfer.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .user_defined_child import user_defined_child

class user_defined(NamedObject[user_defined_child], _CreatableNamedObjectMixin[user_defined_child]):
    """
    'user_defined' child.
    """

    fluent_name = "user-defined"

    child_object_type: user_defined_child = user_defined_child
    """
    child_object_type of user_defined.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .limit_pressure_correction_gradient import limit_pressure_correction_gradient
class skewness_correction(Group):
    """
    'skewness_correction' child.
    """

    fluent_name = "skewness-correction"

    child_names = \
        ['limit_pressure_correction_gradient']

    limit_pressure_correction_gradient: limit_pressure_correction_gradient = limit_pressure_correction_gradient
    """
    limit_pressure_correction_gradient child of skewness_correction.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class repair_face_node_order(Command):
    """
    Reverse order of face nodes if needed.
    """

    fluent_name = "repair-face-node-order"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .x import x
from .x_2 import x_2
from .y import y
from .y_2 import y_2
from .z import z
from .z_2 import z_2
from .azimuthal_start_angle import azimuthal_start_angle
from .azimuthal_stop_angle import azimuthal_stop_angle
from .injection_surfaces import injection_surfaces
from .random_surface_inj import random_surface_inj
class location(Group):
    """
    'location' child.
    """

    fluent_name = "location"

    child_names = \
        ['x', 'x_2', 'y', 'y_2', 'z', 'z_2', 'azimuthal_start_angle',
         'azimuthal_stop_angle', 'injection_surfaces', 'random_surface_inj']

    x: x = x
    """
    x child of location.
    """
    x_2: x_2 = x_2
    """
    x_2 child of location.
    """
    y: y = y
    """
    y child of location.
    """
    y_2: y_2 = y_2
    """
    y_2 child of location.
    """
    z: z = z
    """
    z child of location.
    """
    z_2: z_2 = z_2
    """
    z_2 child of location.
    """
    azimuthal_start_angle: azimuthal_start_angle = azimuthal_start_angle
    """
    azimuthal_start_angle child of location.
    """
    azimuthal_stop_angle: azimuthal_stop_angle = azimuthal_stop_angle
    """
    azimuthal_stop_angle child of location.
    """
    injection_surfaces: injection_surfaces = injection_surfaces
    """
    injection_surfaces child of location.
    """
    random_surface_inj: random_surface_inj = random_surface_inj
    """
    random_surface_inj child of location.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name_1 import name
from .python_name import python_name
from .type_2 import type
from .display_options import display_options
class cell_registers_child(Group):
    """
    'child_object_type' of cell_registers.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'python_name', 'type', 'display_options']

    name: name = name
    """
    name child of cell_registers_child.
    """
    python_name: python_name = python_name
    """
    python_name child of cell_registers_child.
    """
    type: type = type
    """
    type child of cell_registers_child.
    """
    display_options: display_options = display_options
    """
    display_options child of cell_registers_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .mg_controls_child import mg_controls_child

class mg_controls(NamedObject[mg_controls_child], _NonCreatableNamedObjectMixin[mg_controls_child]):
    """
    'mg_controls' child.
    """

    fluent_name = "mg-controls"

    child_object_type: mg_controls_child = mg_controls_child
    """
    child_object_type of mg_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .file_suffix_type import file_suffix_type
from .file_decimal_digit import file_decimal_digit
class append_file_name_with(Group):
    """
    Set the suffix for auto-saved files. The file name can be appended by flow-time, time-step value or by user specified flags in file name.
    """

    fluent_name = "append-file-name-with"

    child_names = \
        ['file_suffix_type', 'file_decimal_digit']

    file_suffix_type: file_suffix_type = file_suffix_type
    """
    file_suffix_type child of append_file_name_with.
    """
    file_decimal_digit: file_decimal_digit = file_decimal_digit
    """
    file_decimal_digit child of append_file_name_with.
    """



import functools
from typing import Callable

import grpc


def catch_grpc_error(f: Callable) -> Callable:
    """Decorator to catch gRPC errors."""

    @functools.wraps(f)
    def func(*args, **kwargs) -> Callable:
        try:
            return f(*args, **kwargs)
        except grpc.RpcError as ex:
            raise RuntimeError(ex.details()) from None

    return func



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class select_from_available(Boolean):
    """
    'select_from_available' child.
    """

    fluent_name = "select-from-available?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class max_fine_relaxations(Integer):
    """
    Maximum number of fine level relaxations for flexible cycle.
    """

    fluent_name = "max-fine-relaxations"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class les_embedded_c_smag(Real):
    """
    'les_embedded_c_smag' child.
    """

    fluent_name = "les-embedded-c-smag"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .geometry_child import geometry_child

class geometry(NamedObject[geometry_child], _CreatableNamedObjectMixin[geometry_child]):
    """
    Main menu to define a disk-section:
    
     - delete : delete a disk-section% - edit   : edit a disk-section
     - new    : create a new disk-section
     - rename : rename a vbm disk-section.
    
    """

    fluent_name = "geometry"

    child_object_type: geometry_child = geometry_child
    """
    child_object_type of geometry.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .keep_linearized_source_terms_constant import keep_linearized_source_terms_constant
from .linearize_source_terms import linearize_source_terms
from .linearized_source_terms_limiter import linearized_source_terms_limiter
class linearization(Group):
    """
    Menu containing options to enable/disable linearization of DPM source terms. 
    Please note that source term linearization is only available if the node-based averaging option is not active.
    """

    fluent_name = "linearization"

    child_names = \
        ['keep_linearized_source_terms_constant', 'linearize_source_terms',
         'linearized_source_terms_limiter']

    keep_linearized_source_terms_constant: keep_linearized_source_terms_constant = keep_linearized_source_terms_constant
    """
    keep_linearized_source_terms_constant child of linearization.
    """
    linearize_source_terms: linearize_source_terms = linearize_source_terms
    """
    linearize_source_terms child of linearization.
    """
    linearized_source_terms_limiter: linearized_source_terms_limiter = linearized_source_terms_limiter
    """
    linearized_source_terms_limiter child of linearization.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .surface import surface
class delete(Command):
    """
    Delete surface mesh.
    
    Parameters
    ----------
        surface : str
            'surface' child.
    
    """

    fluent_name = "delete"

    argument_names = \
        ['surface']

    surface: surface = surface
    """
    surface argument of delete.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name_1 import name
from .definition import definition
from .description import description
from .parameterid import parameterid
from .parametername import parametername
from .unit import unit
from .input_parameter import input_parameter
from .output_parameter import output_parameter
from .get_value import get_value
class named_expressions_child(Group):
    """
    'child_object_type' of named_expressions.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'definition', 'description', 'parameterid', 'parametername',
         'unit', 'input_parameter', 'output_parameter']

    name: name = name
    """
    name child of named_expressions_child.
    """
    definition: definition = definition
    """
    definition child of named_expressions_child.
    """
    description: description = description
    """
    description child of named_expressions_child.
    """
    parameterid: parameterid = parameterid
    """
    parameterid child of named_expressions_child.
    """
    parametername: parametername = parametername
    """
    parametername child of named_expressions_child.
    """
    unit: unit = unit
    """
    unit child of named_expressions_child.
    """
    input_parameter: input_parameter = input_parameter
    """
    input_parameter child of named_expressions_child.
    """
    output_parameter: output_parameter = output_parameter
    """
    output_parameter child of named_expressions_child.
    """
    query_names = \
        ['get_value']

    get_value: get_value = get_value
    """
    get_value query of named_expressions_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .turbulence_options import turbulence_options
from .enable_8 import enable
class warped_face_gradient_correction(Group):
    """
    Enter warped-face-gradient-correction menu.
    """

    fluent_name = "warped-face-gradient-correction"

    child_names = \
        ['turbulence_options']

    turbulence_options: turbulence_options = turbulence_options
    """
    turbulence_options child of warped_face_gradient_correction.
    """
    command_names = \
        ['enable']

    enable: enable = enable
    """
    enable command of warped_face_gradient_correction.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .multi_phase_setting import multi_phase_setting
from .single_phase_setting import single_phase_setting
class hybrid_nita_settings(Group):
    """
    'hybrid_nita_settings' child.
    """

    fluent_name = "hybrid-nita-settings"

    child_names = \
        ['multi_phase_setting', 'single_phase_setting']

    multi_phase_setting: multi_phase_setting = multi_phase_setting
    """
    multi_phase_setting child of hybrid_nita_settings.
    """
    single_phase_setting: single_phase_setting = single_phase_setting
    """
    single_phase_setting child of hybrid_nita_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .location import location
from .matrix import matrix
from .cone_settings import cone_settings
from .velocity import velocity
from .angular_velocity import angular_velocity
from .flow_rate_1 import flow_rate
from .times import times
from .diameter_1 import diameter
from .temperature import temperature
from .temperature_2 import temperature_2
class initial_props(Group):
    """
    'initial_props' child.
    """

    fluent_name = "initial-props"

    child_names = \
        ['location', 'matrix', 'cone_settings', 'velocity',
         'angular_velocity', 'flow_rate', 'times', 'diameter', 'temperature',
         'temperature_2']

    location: location = location
    """
    location child of initial_props.
    """
    matrix: matrix = matrix
    """
    matrix child of initial_props.
    """
    cone_settings: cone_settings = cone_settings
    """
    cone_settings child of initial_props.
    """
    velocity: velocity = velocity
    """
    velocity child of initial_props.
    """
    angular_velocity: angular_velocity = angular_velocity
    """
    angular_velocity child of initial_props.
    """
    flow_rate: flow_rate = flow_rate
    """
    flow_rate child of initial_props.
    """
    times: times = times
    """
    times child of initial_props.
    """
    diameter: diameter = diameter
    """
    diameter child of initial_props.
    """
    temperature: temperature = temperature
    """
    temperature child of initial_props.
    """
    temperature_2: temperature_2 = temperature_2
    """
    temperature_2 child of initial_props.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .histogram_options import histogram_options
from .histogram_parameters import histogram_parameters
from .plot_write_sample import plot_write_sample
from .reduction import reduction
from .dpm_sample_contour_plots import dpm_sample_contour_plots
from .compute_sample import compute_sample
from .delete_sample import delete_sample
from .list_samples import list_samples
from .read_sample_file import read_sample_file
class histogram(Group):
    """
    'histogram' child.
    """

    fluent_name = "histogram"

    child_names = \
        ['histogram_options', 'histogram_parameters', 'plot_write_sample',
         'reduction', 'dpm_sample_contour_plots']

    histogram_options: histogram_options = histogram_options
    """
    histogram_options child of histogram.
    """
    histogram_parameters: histogram_parameters = histogram_parameters
    """
    histogram_parameters child of histogram.
    """
    plot_write_sample: plot_write_sample = plot_write_sample
    """
    plot_write_sample child of histogram.
    """
    reduction: reduction = reduction
    """
    reduction child of histogram.
    """
    dpm_sample_contour_plots: dpm_sample_contour_plots = dpm_sample_contour_plots
    """
    dpm_sample_contour_plots child of histogram.
    """
    command_names = \
        ['compute_sample', 'delete_sample', 'list_samples',
         'read_sample_file']

    compute_sample: compute_sample = compute_sample
    """
    compute_sample command of histogram.
    """
    delete_sample: delete_sample = delete_sample
    """
    delete_sample command of histogram.
    """
    list_samples: list_samples = list_samples
    """
    list_samples command of histogram.
    """
    read_sample_file: read_sample_file = read_sample_file
    """
    read_sample_file command of histogram.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .particle_mixture_child import particle_mixture_child

class particle_mixture(NamedObject[particle_mixture_child], _CreatableNamedObjectMixin[particle_mixture_child]):
    """
    'particle_mixture' child.
    """

    fluent_name = "particle-mixture"

    child_object_type: particle_mixture_child = particle_mixture_child
    """
    child_object_type of particle_mixture.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name import name
from .surface_name_list import surface_name_list
from .wall_function import wall_function
from .htc_on_walls import htc_on_walls
class taitherm(Command):
    """
    Write a TAITherm file.
    
    Parameters
    ----------
        name : str
            'name' child.
        surface_name_list : typing.List[str]
            'surface_name_list' child.
        wall_function : bool
            'wall_function' child.
        htc_on_walls : bool
            'htc_on_walls' child.
    
    """

    fluent_name = "taitherm"

    argument_names = \
        ['name', 'surface_name_list', 'wall_function', 'htc_on_walls']

    name: name = name
    """
    name argument of taitherm.
    """
    surface_name_list: surface_name_list = surface_name_list
    """
    surface_name_list argument of taitherm.
    """
    wall_function: wall_function = wall_function
    """
    wall_function argument of taitherm.
    """
    htc_on_walls: htc_on_walls = htc_on_walls
    """
    htc_on_walls argument of taitherm.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .number_of_blades import number_of_blades
from .tip_radius import tip_radius
from .root_radius import root_radius
from .rotor_speed import rotor_speed
class basic_info(Group):
    """
    Menu to define the rotor basic informations:
    
     - Number of Blades 
     - Tip Radius 
     - Root Radius , 
     - Rotor Speed  , 
    
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "basic-info"

    child_names = \
        ['number_of_blades', 'tip_radius', 'root_radius', 'rotor_speed']

    number_of_blades: number_of_blades = number_of_blades
    """
    number_of_blades child of basic_info.
    """
    tip_radius: tip_radius = tip_radius
    """
    tip_radius child of basic_info.
    """
    root_radius: root_radius = root_radius
    """
    root_radius child of basic_info.
    """
    rotor_speed: rotor_speed = rotor_speed
    """
    rotor_speed child of basic_info.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name_1 import name
from .old_props import old_props
from .file_name import file_name
from .frequency import frequency
from .flow_frequency import flow_frequency
from .itr_index import itr_index
from .run_index import run_index
from .frequency_of import frequency_of
from .report_defs import report_defs
from .print_1 import print
from .active import active
from .write_instantaneous_values import write_instantaneous_values
class report_files_child(Group):
    """
    'child_object_type' of report_files.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'old_props', 'file_name', 'frequency', 'flow_frequency',
         'itr_index', 'run_index', 'frequency_of', 'report_defs', 'print',
         'active', 'write_instantaneous_values']

    name: name = name
    """
    name child of report_files_child.
    """
    old_props: old_props = old_props
    """
    old_props child of report_files_child.
    """
    file_name: file_name = file_name
    """
    file_name child of report_files_child.
    """
    frequency: frequency = frequency
    """
    frequency child of report_files_child.
    """
    flow_frequency: flow_frequency = flow_frequency
    """
    flow_frequency child of report_files_child.
    """
    itr_index: itr_index = itr_index
    """
    itr_index child of report_files_child.
    """
    run_index: run_index = run_index
    """
    run_index child of report_files_child.
    """
    frequency_of: frequency_of = frequency_of
    """
    frequency_of child of report_files_child.
    """
    report_defs: report_defs = report_defs
    """
    report_defs child of report_files_child.
    """
    print: print = print
    """
    print child of report_files_child.
    """
    active: active = active
    """
    active child of report_files_child.
    """
    write_instantaneous_values: write_instantaneous_values = write_instantaneous_values
    """
    write_instantaneous_values child of report_files_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class turbulence_options(String):
    """
     Options:
     Legacy computations 
     New computations .
    """

    fluent_name = "turbulence-options"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .expert import expert
from .relative_convergence_criterion import relative_convergence_criterion
from .max_iterations_per_timestep import max_iterations_per_timestep
class acoustics_wave_equation_controls(Group):
    """
    'acoustics_wave_equation_controls' child.
    """

    fluent_name = "acoustics-wave-equation-controls"

    child_names = \
        ['expert', 'relative_convergence_criterion',
         'max_iterations_per_timestep']

    expert: expert = expert
    """
    expert child of acoustics_wave_equation_controls.
    """
    relative_convergence_criterion: relative_convergence_criterion = relative_convergence_criterion
    """
    relative_convergence_criterion child of acoustics_wave_equation_controls.
    """
    max_iterations_per_timestep: max_iterations_per_timestep = max_iterations_per_timestep
    """
    max_iterations_per_timestep child of acoustics_wave_equation_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .phase_4 import phase
from .geom_disable import geom_disable
from .geom_dir_spec import geom_dir_spec
from .geom_dir_x import geom_dir_x
from .geom_dir_y import geom_dir_y
from .geom_dir_z import geom_dir_z
from .geom_levels import geom_levels
from .geom_bgthread import geom_bgthread
from .porous_jump_turb_wall_treatment import porous_jump_turb_wall_treatment
from .dir import dir
from .average_dp import average_dp
from .c_1 import c
from .limit_range import limit_range
from .v_min import v_min
from .v_max import v_max
from .strength import strength
from .profile_dp import profile_dp
from .dp_profile import dp_profile
from .swirl_model import swirl_model
from .fan_vr import fan_vr
from .fr import fr
from .hub import hub
from .axis_origin_2 import axis_origin
from .axis_direction_2 import axis_direction
from .profile_vt import profile_vt
from .vt_profile import vt_profile
from .profile_vr import profile_vr
from .vr_profile import vr_profile
from .swirl_factor import swirl_factor
from .dpm_bc_type import dpm_bc_type
from .dpm_bc_collision_partner import dpm_bc_collision_partner
from .reinj_inj import reinj_inj
from .dpm_bc_udf import dpm_bc_udf
from .new_fan_definition import new_fan_definition
class fan_child(Group):
    """
    'child_object_type' of fan.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread',
         'porous_jump_turb_wall_treatment', 'dir', 'average_dp', 'c',
         'limit_range', 'v_min', 'v_max', 'strength', 'profile_dp',
         'dp_profile', 'swirl_model', 'fan_vr', 'fr', 'hub', 'axis_origin',
         'axis_direction', 'profile_vt', 'vt_profile', 'profile_vr',
         'vr_profile', 'swirl_factor', 'dpm_bc_type',
         'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'new_fan_definition']

    phase: phase = phase
    """
    phase child of fan_child.
    """
    geom_disable: geom_disable = geom_disable
    """
    geom_disable child of fan_child.
    """
    geom_dir_spec: geom_dir_spec = geom_dir_spec
    """
    geom_dir_spec child of fan_child.
    """
    geom_dir_x: geom_dir_x = geom_dir_x
    """
    geom_dir_x child of fan_child.
    """
    geom_dir_y: geom_dir_y = geom_dir_y
    """
    geom_dir_y child of fan_child.
    """
    geom_dir_z: geom_dir_z = geom_dir_z
    """
    geom_dir_z child of fan_child.
    """
    geom_levels: geom_levels = geom_levels
    """
    geom_levels child of fan_child.
    """
    geom_bgthread: geom_bgthread = geom_bgthread
    """
    geom_bgthread child of fan_child.
    """
    porous_jump_turb_wall_treatment: porous_jump_turb_wall_treatment = porous_jump_turb_wall_treatment
    """
    porous_jump_turb_wall_treatment child of fan_child.
    """
    dir: dir = dir
    """
    dir child of fan_child.
    """
    average_dp: average_dp = average_dp
    """
    average_dp child of fan_child.
    """
    c: c = c
    """
    c child of fan_child.
    """
    limit_range: limit_range = limit_range
    """
    limit_range child of fan_child.
    """
    v_min: v_min = v_min
    """
    v_min child of fan_child.
    """
    v_max: v_max = v_max
    """
    v_max child of fan_child.
    """
    strength: strength = strength
    """
    strength child of fan_child.
    """
    profile_dp: profile_dp = profile_dp
    """
    profile_dp child of fan_child.
    """
    dp_profile: dp_profile = dp_profile
    """
    dp_profile child of fan_child.
    """
    swirl_model: swirl_model = swirl_model
    """
    swirl_model child of fan_child.
    """
    fan_vr: fan_vr = fan_vr
    """
    fan_vr child of fan_child.
    """
    fr: fr = fr
    """
    fr child of fan_child.
    """
    hub: hub = hub
    """
    hub child of fan_child.
    """
    axis_origin: axis_origin = axis_origin
    """
    axis_origin child of fan_child.
    """
    axis_direction: axis_direction = axis_direction
    """
    axis_direction child of fan_child.
    """
    profile_vt: profile_vt = profile_vt
    """
    profile_vt child of fan_child.
    """
    vt_profile: vt_profile = vt_profile
    """
    vt_profile child of fan_child.
    """
    profile_vr: profile_vr = profile_vr
    """
    profile_vr child of fan_child.
    """
    vr_profile: vr_profile = vr_profile
    """
    vr_profile child of fan_child.
    """
    swirl_factor: swirl_factor = swirl_factor
    """
    swirl_factor child of fan_child.
    """
    dpm_bc_type: dpm_bc_type = dpm_bc_type
    """
    dpm_bc_type child of fan_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner = dpm_bc_collision_partner
    """
    dpm_bc_collision_partner child of fan_child.
    """
    reinj_inj: reinj_inj = reinj_inj
    """
    reinj_inj child of fan_child.
    """
    dpm_bc_udf: dpm_bc_udf = dpm_bc_udf
    """
    dpm_bc_udf child of fan_child.
    """
    new_fan_definition: new_fan_definition = new_fan_definition
    """
    new_fan_definition child of fan_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .min_value import min_value
from .max_value import max_value
class clip_to_range(Group):
    """
    'clip_to_range' child.
    """

    fluent_name = "clip-to-range"

    child_names = \
        ['min_value', 'max_value']

    min_value: min_value = min_value
    """
    min_value child of clip_to_range.
    """
    max_value: max_value = max_value
    """
    max_value child of clip_to_range.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
class species(Group):
    """
    'species' child.
    """

    fluent_name = "species"

    child_names = \
        ['option']

    option: option = option
    """
    option child of species.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .child_object_type_child_1 import child_object_type_child

class moving_mesh_axis_origin(ListObject[child_object_type_child]):
    """
    'moving_mesh_axis_origin' child.
    """

    fluent_name = "moving-mesh-axis-origin"

    child_object_type: child_object_type_child = child_object_type_child
    """
    child_object_type of moving_mesh_axis_origin.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .display import display
from .contour_child import contour_child

class contour(NamedObject[contour_child], _CreatableNamedObjectMixin[contour_child]):
    """
    'contour' child.
    """

    fluent_name = "contour"

    command_names = \
        ['display']

    display: display = display
    """
    display command of contour.
    """
    child_object_type: contour_child = contour_child
    """
    child_object_type of contour.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class auto_time_step_size_cal(Boolean):
    """
    Enable/disable use of automatic time step size calculation.
    """

    fluent_name = "auto-time-step-size-cal?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .from_name import from_name
from .new_name import new_name
class copy(Command):
    """
    Copy graphics object.
    
    Parameters
    ----------
        from_name : str
            'from_name' child.
        new_name : str
            'new_name' child.
    
    """

    fluent_name = "copy"

    argument_names = \
        ['from_name', 'new_name']

    from_name: from_name = from_name
    """
    from_name argument of copy.
    """
    new_name: new_name = new_name
    """
    new_name argument of copy.
    """



from functools import partial
import os
import tempfile

import ansys.fluent.core as pyfluent
from ansys.fluent.core.utils.async_execution import asynchronous
from ansys.fluent.core.utils.logging import LOG


@asynchronous
def read_case_into(solver, file_type, file_name):
    LOG.info(f"Trying to read case: {file_name}")
    solver.upload(file_name)
    solver.file.read(file_name=file_name, file_type=file_type)
    LOG.info(f"Have read case: {file_name}")


def read_case_into_each(solvers, file_type, file_name):
    reads = []
    for solver in solvers:
        reads.append(read_case_into(solver, file_type, file_name))
    for r in reads:
        r.result()


def transfer_case(
    source_instance,
    solvers,
    file_type,
    file_name_stem,
    num_files_to_try,
    clean_up_temp_file,
    overwrite_previous,
):
    """Transfer case between instances.

    Parameters
    ----------
    source_instance : object
        Fluent instance (tested for meshing instance)
    solvers : iterable
        Sequence of solver instances
    file_type : str
        "case" or "mesh"
    file_name_stem : str
        Optional file name stem
    num_files_to_try : int
        Optional number of files to try to write,
        each with a different generated name.
        Defaults to 1
    clean_up_mesh_file: bool
        Whether to remove the file at the end
    overwrite_previous: bool
        Whether to overwrite the file if it already exists
    Returns
    -------
    None
    """
    for idx in range(num_files_to_try):
        file_name = (file_name_stem or "temp_case_file_") + "_" + str(idx)
        folder = tempfile.mkdtemp(prefix="temp_store-", dir=pyfluent.EXAMPLES_PATH)
        file_name = os.path.join(folder, file_name)
        LOG.info(f"Trying to save mesh from meshing session: {file_name}")
        if overwrite_previous or not os.path.isfile(file_name):
            LOG.info(f"Saving mesh from meshing session: {file_name}")
            file_menu = source_instance.tui.file
            writer = partial(
                file_menu.write_mesh if file_type == "mesh" else file_menu.write_case,
                file_name,
            )
            if os.path.isfile(file_name):
                writer("y")
            else:
                writer()
            full_file_name = (
                file_name + "." + ("msh.h5" if file_type == "mesh" else "cas.h5")
            )
            source_instance.download(full_file_name, ".")
            LOG.info(f"Saved mesh from meshing session: {full_file_name}")
            read_case_into_each(solvers, file_type, full_file_name)
            if clean_up_temp_file:
                try:
                    os.remove(full_file_name)
                except BaseException as ex:
                    LOG.warn(
                        f"Encountered exception while cleaning up during case transfer {ex}"
                    )
            return
    raise RuntimeError("Could not write mesh from meshing session.")



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .spatial_discretization_limiter import spatial_discretization_limiter
class expert(Group):
    """
    'expert' child.
    """

    fluent_name = "expert"

    child_names = \
        ['spatial_discretization_limiter']

    spatial_discretization_limiter: spatial_discretization_limiter = spatial_discretization_limiter
    """
    spatial_discretization_limiter child of expert.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .init_type import init_type
class initialize(Command):
    """
    'initialize' command.
    
    Parameters
    ----------
        init_type : str
            'init_type' child.
    
    """

    fluent_name = "initialize"

    argument_names = \
        ['init_type']

    init_type: init_type = init_type
    """
    init_type argument of initialize.
    """



"""Wrappers over FieldData gRPC service of Fluent."""
from enum import IntEnum
from functools import reduce
from typing import Dict, List, Optional, Tuple, Union

import grpc
import numpy as np

from ansys.api.fluent.v0 import field_data_pb2 as FieldDataProtoModule
from ansys.api.fluent.v0 import field_data_pb2_grpc as FieldGrpcModule
from ansys.fluent.core.services.error_handler import catch_grpc_error
from ansys.fluent.core.services.interceptors import TracingInterceptor


class FieldDataService:
    def __init__(self, channel: grpc.Channel, metadata):
        tracing_interceptor = TracingInterceptor()
        intercept_channel = grpc.intercept_channel(channel, tracing_interceptor)
        self.__stub = FieldGrpcModule.FieldDataStub(intercept_channel)
        self.__metadata = metadata

    @catch_grpc_error
    def get_range(self, request):
        return self.__stub.GetRange(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_fields_info(self, request):
        return self.__stub.GetFieldsInfo(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_vector_fields_info(self, request):
        return self.__stub.GetVectorFieldsInfo(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_surfaces_info(self, request):
        return self.__stub.GetSurfacesInfo(request, metadata=self.__metadata)

    @catch_grpc_error
    def get_fields(self, request):
        return self.__stub.GetFields(request, metadata=self.__metadata)


class FieldInfo:
    """Provides access to Fluent field information.

    Methods
    -------
    get_range(field: str, node_value: bool, surface_ids: List[int])
    -> List[float]
        Get the range (minimum and maximum values) of the field.

    get_fields_info(self) -> dict
        Get fields information (field name, domain, and section).

    get_vector_fields_info(self) -> dict
        Get vector fields information (vector of and components).

    get_surfaces_info(self) -> dict
        Get surfaces information (surface name, ID, and type).
    """

    def __init__(self, service: FieldDataService):
        self._service = service

    def get_range(
        self, field: str, node_value: bool = False, surface_ids: List[int] = None
    ) -> List[float]:
        if not surface_ids:
            surface_ids = []
        request = FieldDataProtoModule.GetRangeRequest()
        request.fieldName = field
        request.nodeValue = node_value
        request.surfaceid.extend(
            [FieldDataProtoModule.SurfaceId(id=int(id)) for id in surface_ids]
        )
        response = self._service.get_range(request)
        return [response.minimum, response.maximum]

    def get_fields_info(self) -> dict:
        request = FieldDataProtoModule.GetFieldsInfoRequest()
        response = self._service.get_fields_info(request)
        return {
            field_info.solverName: {
                "display_name": field_info.displayName,
                "section": field_info.section,
                "domain": field_info.domain,
            }
            for field_info in response.fieldInfo
        }

    def get_vector_fields_info(self) -> dict:
        request = FieldDataProtoModule.GetVectorFieldsInfoRequest()
        response = self._service.get_vector_fields_info(request)
        return {
            vector_field_info.displayName: {
                "x-component": vector_field_info.xComponent,
                "y-component": vector_field_info.yComponent,
                "z-component": vector_field_info.zComponent,
            }
            for vector_field_info in response.vectorFieldInfo
        }

    def get_surfaces_info(self) -> dict:
        request = FieldDataProtoModule.GetSurfacesInfoResponse()
        response = self._service.get_surfaces_info(request)
        info = {
            surface_info.surfaceName: {
                "surface_id": [surf.id for surf in surface_info.surfaceId],
                "zone_id": surface_info.zoneId.id,
                "zone_type": surface_info.zoneType,
                "type": surface_info.type,
            }
            for surface_info in response.surfaceInfo
        }
        return info


class SurfaceDataType(IntEnum):
    """Provides surface data types."""

    Vertices = 1
    FacesConnectivity = 2
    FacesNormal = 3
    FacesCentroid = 4


class FieldTransaction:
    """Populates Fluent field data on surfaces."""

    def __init__(self, service: FieldDataService, field_info: FieldInfo):
        self._service = service
        self._field_info = field_info
        self._fields_request = get_fields_request()

    def add_surfaces_request(
        self,
        surface_ids: Optional[List[int]] = None,
        surface_names: Optional[List[str]] = None,
        overset_mesh: Optional[bool] = False,
        provide_vertices: Optional[bool] = True,
        provide_faces: Optional[bool] = True,
        provide_faces_centroid: Optional[bool] = False,
        provide_faces_normal: Optional[bool] = False,
    ) -> None:
        """Add request to get surface data (vertices, face connectivity,
        centroids, and normals).

        Parameters
        ----------
        surface_ids : List[int], optional
            List of surface IDS for the surface data.
        surface_names: List[str], optional
            List of surface names for the surface data.
        overset_mesh : bool, optional
            Whether to get the overset met. The default is ``False``.
        provide_vertices : bool, optional
            Whether to get node coordinates. The default is ``True``.
        provide_faces : bool, optional
            Whether to get face connectivity. The default is ``True``.
        provide_faces_centroid : bool, optional
            Whether to get face centroids. The default is ``False``.
        provide_faces_normal : bool, optional
            Whether to get faces normal. The default is ``False``

        Returns
        -------
        None
        """
        surface_ids = _get_surface_ids(
            field_info=self._field_info,
            surface_ids=surface_ids,
            surface_names=surface_names,
        )
        self._fields_request.surfaceRequest.extend(
            [
                FieldDataProtoModule.SurfaceRequest(
                    surfaceId=surface_id,
                    oversetMesh=overset_mesh,
                    provideFaces=provide_faces,
                    provideVertices=provide_vertices,
                    provideFacesCentroid=provide_faces_centroid,
                    provideFacesNormal=provide_faces_normal,
                )
                for surface_id in surface_ids
            ]
        )

    def add_scalar_fields_request(
        self,
        field_name: str,
        surface_ids: Optional[List[int]] = None,
        surface_names: Optional[List[str]] = None,
        node_value: Optional[bool] = True,
        boundary_value: Optional[bool] = False,
    ) -> None:
        """Add request to get scalar field data on surfaces.

        Parameters
        ----------
        field_name : str
            Name of the scalar field.
        surface_ids : List[int], optional
            List of surface IDs for scalar field data.
        surface_names: List[str], optional
            List of surface names for scalar field data.
        node_value : bool, optional
            Whether to provide the nodal location. The default is ``True``. If
            ``False``, the element location is provided.
        boundary_value : bool, optional
            Whether to provide the slip velocity at the wall boundaries. The default
            is ``False``. When ``True``, no slip velocity is provided.

        Returns
        -------
        None
        """
        surface_ids = _get_surface_ids(
            field_info=self._field_info,
            surface_ids=surface_ids,
            surface_names=surface_names,
        )
        self._fields_request.scalarFieldRequest.extend(
            [
                FieldDataProtoModule.ScalarFieldRequest(
                    surfaceId=surface_id,
                    scalarFieldName=field_name,
                    dataLocation=FieldDataProtoModule.DataLocation.Nodes
                    if node_value
                    else FieldDataProtoModule.DataLocation.Elements,
                    provideBoundaryValues=boundary_value,
                )
                for surface_id in surface_ids
            ]
        )

    def add_vector_fields_request(
        self,
        field_name: str,
        surface_ids: Optional[List[int]] = None,
        surface_names: Optional[List[str]] = None,
    ) -> None:
        """Add request to get vector field data on surfaces.

        Parameters
        ----------
        field_name : str
            Name of the vector field.
        surface_ids : List[int], optional
            List of surface IDs for vector field data.
        surface_names: List[str], optional
            List of surface names for vector field data.

        Returns
        -------
        None
        """
        surface_ids = _get_surface_ids(
            field_info=self._field_info,
            surface_ids=surface_ids,
            surface_names=surface_names,
        )
        self._fields_request.vectorFieldRequest.extend(
            [
                FieldDataProtoModule.VectorFieldRequest(
                    surfaceId=surface_id,
                    vectorFieldName=field_name,
                )
                for surface_id in surface_ids
            ]
        )

    def add_pathlines_fields_request(
        self,
        field_name: str,
        surface_ids: Optional[List[int]] = None,
        surface_names: Optional[List[str]] = None,
        additional_field_name: Optional[str] = "",
        provide_particle_time_field: Optional[bool] = False,
        node_value: Optional[bool] = True,
        steps: Optional[int] = 500,
        step_size: Optional[float] = 0.01,
        skip: Optional[int] = 0,
        reverse: Optional[bool] = False,
        accuracy_control_on: Optional[bool] = False,
        tolerance: Optional[float] = 0.001,
        coarsen: Optional[int] = 1,
        velocity_domain: Optional[str] = "all-phases",
        zones: Optional[list] = [],
    ) -> None:
        """Add request to get pathlines field on surfaces.

        Parameters
        ----------
        field_name : str
            Name of the scalar field to color pathlines.
        surface_ids : List[int], optional
            List of surface IDs for pathlines field data.
        surface_names : List[str], optional
            List of surface names for pathlines field data.
        additional_field_name : str, optional
            Additional field if required.
        provide_particle_time_field: bool, optional
            Whether to provide the particle time. The default is ``False``.
        node_value : bool, optional
                    Whether to provide the nodal values. The default is ``True``. If
                    ``False``, element values are provided.
        steps: int, optional
            Pathlines steps. The default is ``500``
        step_size: float, optional
            Pathlines step size. The default is ``0.01``.
        skip: int, optional
            Pathlines to skip. The default is ``0``.
        reverse: bool, optional
            Whether to draw pathlines in reverse direction. The default is ``False``.
        tolerance: float, optional
            Pathlines tolerance. The default is ``0.001``.
        coarsen: int, optional
            Pathlines coarsen. The default is ``1``.
        velocity_domain: str, optional
            Domain for pathlines. The default is ``"all-phases"``.
        zones: list, optional
            Zones for pathlines. The default is ``[]``.
        Returns
        -------
        None
        """
        surface_ids = _get_surface_ids(
            field_info=self._field_info,
            surface_ids=surface_ids,
            surface_names=surface_names,
        )
        self._fields_request.pathlinesFieldRequest.extend(
            [
                FieldDataProtoModule.PathlinesFieldRequest(
                    surfaceId=surface_id,
                    field=field_name,
                    additionalField=additional_field_name,
                    provideParticleTimeField=provide_particle_time_field,
                    dataLocation=FieldDataProtoModule.DataLocation.Nodes
                    if node_value
                    else FieldDataProtoModule.DataLocation.Elements,
                    steps=steps,
                    stepSize=step_size,
                    skip=skip,
                    reverse=reverse,
                    accuracyControlOn=accuracy_control_on,
                    tolerance=tolerance,
                    coarsen=coarsen,
                    velocityDomain=velocity_domain,
                    zones=zones,
                )
                for surface_id in surface_ids
            ]
        )

    def get_fields(self) -> Dict[Union[int, Tuple], Dict[int, Dict[str, np.array]]]:
        """Get data for previously added requests and then clear all requests.

        Returns
        -------
        Dict[int, Dict[int, Dict[str, np.array]]]
            Data is returned as dictionary of dictionaries in the following structure:
            tag Union[int, Tuple]-> surface_id [int] -> field_name [str] -> field_data[np.array]

            The tag is a tuple for Fluent 2023 R1 or later.
        """
        return extract_fields(self._service.get_fields(self._fields_request))

    def __call__(self):
        self.get_fields()


class _FieldDataConstants:
    """Defines constants for Fluent field data."""

    # data mapping
    proto_field_type_to_np_data_type = {
        FieldDataProtoModule.FieldType.INT_ARRAY: np.int32,
        FieldDataProtoModule.FieldType.LONG_ARRAY: np.int64,
        FieldDataProtoModule.FieldType.FLOAT_ARRAY: np.float32,
        FieldDataProtoModule.FieldType.DOUBLE_ARRAY: np.float64,
    }
    chunk_size = 256 * 1024
    bytes_stream = True
    payloadTags = {
        FieldDataProtoModule.PayloadTag.OVERSET_MESH: 1,
        FieldDataProtoModule.PayloadTag.ELEMENT_LOCATION: 2,
        FieldDataProtoModule.PayloadTag.NODE_LOCATION: 4,
        FieldDataProtoModule.PayloadTag.BOUNDARY_VALUES: 8,
    }


def _get_surface_ids(
    field_info: FieldInfo,
    surface_ids: Optional[List[int]] = None,
    surface_names: Optional[List[str]] = None,
    surface_name: Optional[str] = None,
) -> List[int]:
    """Get surface ids' based on surface names or ids'.

    Parameters
    ----------
    surface_ids : List[int], optional
        List of surface IDs.
    surface_names: List[str], optional
        List of surface names.
    surface_name: str, optional
        List of surface name.

    Returns
    -------
    List[int]
    """
    if surface_ids and (surface_name or surface_names):
        raise RuntimeError("Please provide either surface names or surface ids.")
    if not surface_ids:
        surface_ids = []
        if surface_names:
            for surface_name in surface_names:
                surface_ids.append(
                    field_info.get_surfaces_info()[surface_name]["surface_id"]
                )
        elif surface_name:
            surface_ids = field_info.get_surfaces_info()[surface_name]["surface_id"]
        else:
            raise RuntimeError("Please provide either surface names or surface ids.")
    return surface_ids


def get_fields_request():
    """Populates a new field request."""
    return FieldDataProtoModule.GetFieldsRequest(
        provideBytesStream=_FieldDataConstants.bytes_stream,
        chunkSize=_FieldDataConstants.chunk_size,
    )


def merge_pathlines_data(pathlines_data, field):
    """Merge multiple pathlines for a surface to create a single mesh
    object."""

    data = {}
    for surface_id, data_for_surface in pathlines_data.items():
        if "pathlines-count" in data_for_surface:
            pathlines_count = data_for_surface["pathlines-count"][0]
            pathline_count = 0
            pathline_connectivity = None
            pathline_positions = None
            pathline_field = None
            while pathline_count < pathlines_count:
                line_id = f"pathline-{pathline_count}-line-data"
                position_id = f"pathline-{pathline_count}-position-data"
                field_id = f"pathline-{pathline_count}-field-data"

                pathline_positions = (
                    data_for_surface[position_id]
                    if pathline_positions is None
                    else np.concatenate(
                        (pathline_positions, data_for_surface[position_id])
                    )
                )
                pathline_connectivity = (
                    data_for_surface[line_id]
                    if pathline_connectivity is None
                    else np.concatenate(
                        (pathline_connectivity, data_for_surface[line_id])
                    )
                )
                pathline_field = (
                    data_for_surface[field_id]
                    if pathline_field is None
                    else np.concatenate((pathline_field, data_for_surface[field_id]))
                )
                pathline_count = pathline_count + 1

            data[surface_id] = {
                "faces": pathline_connectivity,
                "vertices": pathline_positions,
                field: pathline_field,
            }
    return data


def extract_fields(chunk_iterator):
    """Extracts field data via a server call."""

    def _get_tag_for_surface_request(surface_request):
        return (("type", "surface-data"),)

    def _get_tag_for_vector_field_request(vector_field_request):
        return (("type", "vector-field"),)

    def _get_tag_for_scalar_field_request(scalar_field_request):
        return (
            ("type", "scalar-field"),
            ("dataLocation", scalar_field_request.dataLocation),
            ("boundaryValues", scalar_field_request.provideBoundaryValues),
        )

    def _get_tag_for_pathlines_field_request(pathlines_field_request):
        return (("type", "pathlines-field"), ("field", pathlines_field_request.field))

    def _extract_field(field_datatype, field_size, chunk_iterator):
        if not chunk_iterator.is_active():
            raise RuntimeError(
                "Unexpectedly encountered empty chunk during field extraction."
            )
        field_arr = np.empty(field_size, dtype=field_datatype)
        field_datatype_item_size = np.dtype(field_datatype).itemsize
        index = 0
        for chunk in chunk_iterator:
            if chunk.bytePayload:
                count = min(
                    len(chunk.bytePayload) // field_datatype_item_size,
                    field_size - index,
                )
                field_arr[index : index + count] = np.frombuffer(
                    chunk.bytePayload, field_datatype, count=count
                )
                index += count
                if index == field_size:
                    return field_arr
            else:
                payload = (
                    chunk.floatPayload.payload
                    or chunk.intPayload.payload
                    or chunk.doublePayload.payload
                    or chunk.longPayload.payload
                )
                count = len(payload)
                field_arr[index : index + count] = np.fromiter(
                    payload, dtype=field_datatype
                )
                index += count
                if index == field_size:
                    return field_arr

    fields_data = {}
    for chunk in chunk_iterator:

        payload_info = chunk.payloadInfo
        field = _extract_field(
            _FieldDataConstants.proto_field_type_to_np_data_type[
                payload_info.fieldType
            ],
            payload_info.fieldSize,
            chunk_iterator,
        )

        surface_id = payload_info.surfaceId

        field_request_info = payload_info.fieldRequestInfo
        request_type = field_request_info.WhichOneof("request")
        if request_type is not None:
            payload_tag_id = (
                _get_tag_for_surface_request(field_request_info.surfaceRequest)
                if request_type == "surfaceRequest"
                else _get_tag_for_scalar_field_request(
                    field_request_info.scalarFieldRequest
                )
                if request_type == "scalarFieldRequest"
                else _get_tag_for_vector_field_request(
                    field_request_info.vectorFieldRequest
                )
                if request_type == "vectorFieldRequest"
                else _get_tag_for_pathlines_field_request(
                    field_request_info.pathlinesFieldRequest
                )
                if request_type == "pathlinesFieldRequest"
                else None
            )
        else:
            payload_tag_id = reduce(
                lambda x, y: x | y,
                [
                    _FieldDataConstants.payloadTags[tag]
                    for tag in payload_info.payloadTag
                ]
                or [0],
            )
        payload_data = fields_data.get(payload_tag_id)
        if not payload_data:
            payload_data = fields_data[payload_tag_id] = {}
        surface_data = payload_data.get(surface_id)
        if surface_data:
            surface_data.update({payload_info.fieldName: field})
        else:
            payload_data[surface_id] = {payload_info.fieldName: field}
    return fields_data


class FieldData:
    """Provides access to Fluent field data on surfaces."""

    def __init__(self, service: FieldDataService, field_info: FieldInfo):
        self._service = service
        self._field_info = field_info

    def new_transaction(self):
        return FieldTransaction(self._service, self._field_info)

    def get_surface_data(
        self,
        data_type: SurfaceDataType,
        surface_ids: Optional[List[int]] = None,
        surface_name: Optional[str] = None,
        overset_mesh: Optional[bool] = False,
    ) -> Dict[int, np.array]:
        """Get surface data (vertices, faces connectivity, centroids, and
        normals).

        Parameters
        ----------
        data_type : SurfaceDataType
            SurfaceDataType Enum member.
        surface_ids : List[int], optional
            List of surface IDs for the surface data.
        surface_name : str, optional
            Surface name for the surface data.
        overset_mesh : bool, optional
            Whether to provide the overset method. The default is ``False``.

        Returns
        -------
        Dict[int, np.array]
            Dictionary containing a map of surface IDs to surface data.
        """
        surface_ids = _get_surface_ids(
            field_info=self._field_info,
            surface_ids=surface_ids,
            surface_name=surface_name,
        )
        fields_request = get_fields_request()
        fields_request.surfaceRequest.extend(
            [
                FieldDataProtoModule.SurfaceRequest(
                    surfaceId=surface_id,
                    oversetMesh=overset_mesh,
                    provideFaces=data_type == SurfaceDataType.FacesConnectivity,
                    provideVertices=data_type == SurfaceDataType.Vertices,
                    provideFacesCentroid=data_type == SurfaceDataType.FacesCentroid,
                    provideFacesNormal=data_type == SurfaceDataType.FacesNormal,
                )
                for surface_id in surface_ids
            ]
        )
        enum_to_field_name = {
            SurfaceDataType.FacesConnectivity: "faces",
            SurfaceDataType.Vertices: "vertices",
            SurfaceDataType.FacesCentroid: "centroid",
            SurfaceDataType.FacesNormal: "face-normal",
        }
        fields = extract_fields(self._service.get_fields(fields_request))
        surface_data = next(iter(fields.values()))
        return {
            surface_id: surface_data[surface_id][enum_to_field_name[data_type]]
            for surface_id in surface_ids
        }

    def get_scalar_field_data(
        self,
        field_name: str,
        surface_ids: Optional[List[int]] = None,
        surface_name: Optional[str] = None,
        node_value: Optional[bool] = True,
        boundary_value: Optional[bool] = False,
    ) -> Dict[int, np.array]:
        """Get scalar field data on a surface.

        Parameters
        ----------
        field_name : str
            Name of the scalar field.
        surface_ids : List[int], optional
            List of surface IDs for scalar field data.
        surface_name: str, optional
            Surface Name for scalar field data.
        node_value : bool, optional
            Whether to provide data for the nodal location. The default is ``True``.
            When ``False``, data is provided for the element location.
        boundary_value : bool, optional
            Whether to provide slip velocity at the wall boundaries. The default is
            ``False``. When ``True``, no slip velocity is provided.

        Returns
        -------
        Dict[int, np.array]
            Dictionary containing a map of surface IDs to the scalar field.
        """
        surface_ids = _get_surface_ids(
            field_info=self._field_info,
            surface_ids=surface_ids,
            surface_name=surface_name,
        )
        fields_request = get_fields_request()
        fields_request.scalarFieldRequest.extend(
            [
                FieldDataProtoModule.ScalarFieldRequest(
                    surfaceId=surface_id,
                    scalarFieldName=field_name,
                    dataLocation=FieldDataProtoModule.DataLocation.Nodes
                    if node_value
                    else FieldDataProtoModule.DataLocation.Elements,
                    provideBoundaryValues=boundary_value,
                )
                for surface_id in surface_ids
            ]
        )

        fields = extract_fields(self._service.get_fields(fields_request))
        scalar_field_data = next(iter(fields.values()))
        return {
            surface_id: scalar_field_data[surface_id][field_name]
            for surface_id in surface_ids
        }

    def get_vector_field_data(
        self,
        field_name: str,
        surface_ids: Optional[List[int]] = None,
        surface_name: Optional[str] = None,
    ) -> Dict[int, Tuple[np.array, float]]:
        """Get vector field data on a surface.

        Parameters
        ----------
        field_name : str
            Name of the vector field.
        surface_ids : List[int], optional
            List of surface IDs for vector field data.
        surface_name: str, optional
            Surface Name for vector field data.

        Returns
        -------
        Dict[int, Tuple[np.array, float]]
            Dictionary containing a map of surface IDs to a tuple of vector field and vector scale.
        """
        surface_ids = _get_surface_ids(
            field_info=self._field_info,
            surface_ids=surface_ids,
            surface_name=surface_name,
        )
        fields_request = get_fields_request()
        fields_request.vectorFieldRequest.extend(
            [
                FieldDataProtoModule.VectorFieldRequest(
                    surfaceId=surface_id,
                    vectorFieldName=field_name,
                )
                for surface_id in surface_ids
            ]
        )
        fields = extract_fields(self._service.get_fields(fields_request))
        vector_field_data = next(iter(fields.values()))
        return {
            surface_id: (
                vector_field_data[surface_id][field_name],
                vector_field_data[surface_id]["vector-scale"][0],
            )
            for surface_id in surface_ids
        }

    def get_pathlines_field_data(
        self,
        field_name: str,
        surface_ids: Optional[List[int]] = None,
        surface_name: Optional[str] = None,
        additional_field_name: Optional[str] = "",
        provide_particle_time_field: Optional[bool] = False,
        node_value: Optional[bool] = True,
        steps: Optional[int] = 500,
        step_size: Optional[float] = 0.01,
        skip: Optional[int] = 0,
        reverse: Optional[bool] = False,
        accuracy_control_on: Optional[bool] = False,
        tolerance: Optional[float] = 0.001,
        coarsen: Optional[int] = 1,
        velocity_domain: Optional[str] = "all-phases",
        zones: Optional[list] = [],
    ) -> Dict[int, Dict[str, np.array]]:
        """Get pathlines field data on a surface.

        Parameters
        ----------
        field_name : str
            Name of the scalar field to color pathlines.
        surface_ids : List[int], optional
            List of surface IDs for pathlines field data.
        surface_name : str, optional
            Surface name for pathlines field data.
        additional_field_name : str, optional
            Additional field if required.
        provide_particle_time_field: bool, optional
            Whether to provide the particle time. The default is ``False``.
        node_value : bool, optional
                    Whether to provide the nodal values. The default is ``True``. If
                    ``False``, element values are provided.
        steps: int, optional
            Pathlines steps. The default is ``500``
        step_size: float, optional
            Pathlines step size. The default is ``0.01``.
        skip: int, optional
            Pathlines to skip. The default is ``0``.
        reverse: bool, optional
            Whether to draw pathlines in reverse direction. The default is ``False``.
        tolerance: float, optional
            Pathlines tolerance. The default is ``0.001``.
        coarsen: int, optional
            Pathlines coarsen. The default is ``1``.
        velocity_domain: str, optional
            Domain for pathlines. The default is ``"all-phases"``.
        zones: list, optional
            Zones for pathlines. The default is ``[]``.

        Returns
        -------
        Dict[int, Dict[str, np.array]]
            Dictionary containing a map of surface IDs to the pathline data
            For example, pathlines connectivity, vertices, and field.
        """
        surface_ids = _get_surface_ids(
            field_info=self._field_info,
            surface_ids=surface_ids,
            surface_name=surface_name,
        )
        fields_request = get_fields_request()
        fields_request.pathlinesFieldRequest.extend(
            [
                FieldDataProtoModule.PathlinesFieldRequest(
                    surfaceId=surface_id,
                    field=field_name,
                    additionalField=additional_field_name,
                    provideParticleTimeField=provide_particle_time_field,
                    dataLocation=FieldDataProtoModule.DataLocation.Nodes
                    if node_value
                    else FieldDataProtoModule.DataLocation.Elements,
                    steps=steps,
                    stepSize=step_size,
                    skip=skip,
                    reverse=reverse,
                    accuracyControlOn=accuracy_control_on,
                    tolerance=tolerance,
                    coarsen=coarsen,
                    velocityDomain=velocity_domain,
                    zones=zones,
                )
                for surface_id in surface_ids
            ]
        )
        fields = extract_fields(self._service.get_fields(fields_request))
        vector_field_data = next(iter(fields.values()))
        pathlines_data = next(iter(fields.values()))
        return merge_pathlines_data(pathlines_data, field_name)



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class solar_shining_factor(Real):
    """
    'solar_shining_factor' child.
    """

    fluent_name = "solar-shining-factor"




"""Module providing generic functionality."""

from abc import ABCMeta
import asyncio
from functools import partial
import time

loop = asyncio.get_event_loop()


class SingletonMeta(type):
    """Meta class for singleton type."""

    _single_instance = None

    def __call__(cls, *args, **kwargs):
        if not cls._single_instance:
            cls._single_instance = super(SingletonMeta, cls).__call__(*args, **kwargs)
        return cls._single_instance


class AbstractSingletonMeta(ABCMeta, SingletonMeta):
    """Meta class for abstract singleton type."""

    pass


def execute_in_event_loop_threadsafe(f):
    """Decorator to execute function in an event loop from another thread."""

    def cb(*args, **kwargs):
        par = partial(f, *args, **kwargs)
        loop.call_soon_threadsafe(par)

    return cb


def execute_in_event_loop(f):
    """Decorator to execute function in an event loop."""

    def cb(*args, **kwargs):
        par = partial(f, *args, **kwargs)
        loop.call_soon(par)

    return cb


def in_notebook():
    """Function to check if application is running in notebook."""
    try:
        from IPython import get_ipython

        if "IPKernelApp" not in get_ipython().config:
            return False
    except (ImportError, AttributeError):
        return False
    return True


def timing(func):
    """Timing function decorator."""

    def wrapper(*args, **kwargs):
        t1 = time.time()
        res = func(*args, **kwargs)
        t2 = time.time()
        print(func.__name__, t2 - t1)
        return res

    return wrapper



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .phase_23 import phase
from .geom_disable import geom_disable
from .geom_dir_spec import geom_dir_spec
from .geom_dir_x import geom_dir_x
from .geom_dir_y import geom_dir_y
from .geom_dir_z import geom_dir_z
from .geom_levels import geom_levels
from .geom_bgthread import geom_bgthread
from .open_channel_wave_bc import open_channel_wave_bc
from .ocw_vel_segregated import ocw_vel_segregated
from .velocity_spec import velocity_spec
from .frame_of_reference import frame_of_reference
from .vmag import vmag
from .wave_velocity_spec import wave_velocity_spec
from .avg_flow_velocity import avg_flow_velocity
from .ocw_ship_vel_spec import ocw_ship_vel_spec
from .ocw_ship_vmag import ocw_ship_vmag
from .moving_object_direction import moving_object_direction
from .ocw_sp_vel_spec import ocw_sp_vel_spec
from .ocw_sp_vmag import ocw_sp_vmag
from .secondary_phase_direction import secondary_phase_direction
from .ocw_pp_vel_spec import ocw_pp_vel_spec
from .ocw_pp_ref_ht import ocw_pp_ref_ht
from .ocw_pp_power_coeff import ocw_pp_power_coeff
from .ocw_pp_vmag import ocw_pp_vmag
from .ocw_pp_vmag_ref import ocw_pp_vmag_ref
from .primary_phase_direction import primary_phase_direction
from .initial_gauge_pressure import initial_gauge_pressure
from .coordinate_system import coordinate_system
from .velocity_1 import velocity
from .flow_direction import flow_direction
from .axis_direction_2 import axis_direction
from .axis_origin_2 import axis_origin
from .omega_swirl import omega_swirl
from .phase_spec import phase_spec
from .wave_bc_type import wave_bc_type
from .ht_local import ht_local
from .ht_bottom import ht_bottom
from .wave_dir_spec import wave_dir_spec
from .reference_direction import reference_direction
from .wave_modeling_type import wave_modeling_type
from .wave_list import wave_list
from .wave_list_shallow import wave_list_shallow
from .wave_spect_method_freq import wave_spect_method_freq
from .wave_spect_factor import wave_spect_factor
from .wave_spect_sig_wave_ht import wave_spect_sig_wave_ht
from .wave_spect_peak_freq import wave_spect_peak_freq
from .wave_spect_min_freq import wave_spect_min_freq
from .wave_spect_max_freq import wave_spect_max_freq
from .wave_spect_freq_components import wave_spect_freq_components
from .wave_spect_method_dir import wave_spect_method_dir
from .wave_spect_s import wave_spect_s
from .wave_spect_mean_angle import wave_spect_mean_angle
from .wave_spect_deviation import wave_spect_deviation
from .wave_spect_dir_components import wave_spect_dir_components
from .t import t
from .non_equil_boundary import non_equil_boundary
from .tve import tve
from .les_spec_name import les_spec_name
from .rfg_number_of_modes import rfg_number_of_modes
from .vm_number_of_vortices import vm_number_of_vortices
from .vm_streamwise_fluct import vm_streamwise_fluct
from .vm_mass_conservation import vm_mass_conservation
from .stg_scale_limiter_type import stg_scale_limiter_type
from .stg_ti_limiter import stg_ti_limiter
from .stg_tvr_limiter import stg_tvr_limiter
from .stg_dw_limiter import stg_dw_limiter
from .volumetric_synthetic_turbulence_generator import volumetric_synthetic_turbulence_generator
from .volumetric_synthetic_turbulence_generator_option import volumetric_synthetic_turbulence_generator_option
from .volumetric_synthetic_turbulence_generator_option_thickness import volumetric_synthetic_turbulence_generator_option_thickness
from .ke_spec import ke_spec
from .nut import nut
from .kl import kl
from .intermit import intermit
from .k import k
from .e import e
from .o import o
from .v2 import v2
from .turb_intensity import turb_intensity
from .turb_length_scale import turb_length_scale
from .turb_hydraulic_diam import turb_hydraulic_diam
from .turb_viscosity_ratio import turb_viscosity_ratio
from .turb_viscosity_ratio_profile import turb_viscosity_ratio_profile
from .rst_spec import rst_spec
from .uu import uu
from .vv import vv
from .ww import ww
from .uv import uv
from .vw import vw
from .uw import uw
from .ksgs_spec import ksgs_spec
from .ksgs import ksgs
from .sgs_turb_intensity import sgs_turb_intensity
from .granular_temperature import granular_temperature
from .iac import iac
from .lsfun import lsfun
from .volume_fraction import volume_fraction
from .species_in_mole_fractions import species_in_mole_fractions
from .mf import mf
from .elec_potential_type import elec_potential_type
from .potential_value import potential_value
from .dual_potential_type import dual_potential_type
from .dual_potential_value import dual_potential_value
from .x_displacement_type import x_displacement_type
from .x_displacement_value import x_displacement_value
from .y_displacement_type import y_displacement_type
from .y_displacement_value import y_displacement_value
from .z_displacement_type import z_displacement_type
from .z_displacement_value import z_displacement_value
from .prob_mode_1 import prob_mode_1
from .prob_mode_2 import prob_mode_2
from .prob_mode_3 import prob_mode_3
from .equ_required import equ_required
from .uds_bc import uds_bc
from .uds import uds
from .pb_disc_bc import pb_disc_bc
from .pb_disc_1 import pb_disc
from .pb_qmom_bc import pb_qmom_bc
from .pb_qmom import pb_qmom
from .pb_smm_bc import pb_smm_bc
from .pb_smm import pb_smm
from .pb_dqmom_bc import pb_dqmom_bc
from .pb_dqmom import pb_dqmom
from .gauge_pressure import gauge_pressure
from .premixc import premixc
from .premixc_var import premixc_var
from .ecfm_sigma import ecfm_sigma
from .inert import inert
from .pollut_no import pollut_no
from .pollut_hcn import pollut_hcn
from .pollut_nh3 import pollut_nh3
from .pollut_n2o import pollut_n2o
from .pollut_urea import pollut_urea
from .pollut_hnco import pollut_hnco
from .pollut_nco import pollut_nco
from .pollut_so2 import pollut_so2
from .pollut_h2s import pollut_h2s
from .pollut_so3 import pollut_so3
from .pollut_sh import pollut_sh
from .pollut_so import pollut_so
from .pollut_soot import pollut_soot
from .pollut_nuclei import pollut_nuclei
from .pollut_ctar import pollut_ctar
from .pollut_hg import pollut_hg
from .pollut_hgcl2 import pollut_hgcl2
from .pollut_hcl import pollut_hcl
from .pollut_hgo import pollut_hgo
from .pollut_cl import pollut_cl
from .pollut_cl2 import pollut_cl2
from .pollut_hgcl import pollut_hgcl
from .pollut_hocl import pollut_hocl
from .radiation_bc import radiation_bc
from .radial_direction import radial_direction
from .coll_dtheta import coll_dtheta
from .coll_dphi import coll_dphi
from .band_q_irrad import band_q_irrad
from .band_q_irrad_diffuse import band_q_irrad_diffuse
from .parallel_collimated_beam import parallel_collimated_beam
from .solar_direction import solar_direction
from .solar_irradiation import solar_irradiation
from .t_b_b_spec import t_b_b_spec
from .t_b_b import t_b_b
from .in_emiss import in_emiss
from .fmean import fmean
from .fvar import fvar
from .fmean2 import fmean2
from .fvar2 import fvar2
from .tss_scalar import tss_scalar
from .dpm_bc_type import dpm_bc_type
from .dpm_bc_collision_partner import dpm_bc_collision_partner
from .reinj_inj import reinj_inj
from .dpm_bc_udf import dpm_bc_udf
from .fensapice_flow_bc_subtype import fensapice_flow_bc_subtype
from .fensapice_drop_bccustom import fensapice_drop_bccustom
from .fensapice_drop_lwc import fensapice_drop_lwc
from .fensapice_drop_dtemp import fensapice_drop_dtemp
from .fensapice_drop_ddiam import fensapice_drop_ddiam
from .fensapice_drop_dv import fensapice_drop_dv
from .fensapice_drop_dx import fensapice_drop_dx
from .fensapice_drop_dy import fensapice_drop_dy
from .fensapice_drop_dz import fensapice_drop_dz
from .fensapice_dpm_surface_injection import fensapice_dpm_surface_injection
from .fensapice_dpm_inj_nstream import fensapice_dpm_inj_nstream
from .fensapice_drop_icc import fensapice_drop_icc
from .fensapice_drop_ctemp import fensapice_drop_ctemp
from .fensapice_drop_cdiam import fensapice_drop_cdiam
from .fensapice_drop_cv import fensapice_drop_cv
from .fensapice_drop_cx import fensapice_drop_cx
from .fensapice_drop_cy import fensapice_drop_cy
from .fensapice_drop_cz import fensapice_drop_cz
from .fensapice_drop_vrh import fensapice_drop_vrh
from .fensapice_drop_vrh_1 import fensapice_drop_vrh_1
from .fensapice_drop_vc import fensapice_drop_vc
from .mixing_plane_thread import mixing_plane_thread
from .solar_fluxes import solar_fluxes
from .solar_shining_factor import solar_shining_factor
from .radiating_s2s_surface import radiating_s2s_surface
from .ac_options import ac_options
from .impedance_0 import impedance_0
from .impedance_1 import impedance_1
from .impedance_2 import impedance_2
from .ac_wave import ac_wave
from .les_spec import les_spec
class velocity_inlet_child(Group):
    """
    'child_object_type' of velocity_inlet.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'open_channel_wave_bc',
         'ocw_vel_segregated', 'velocity_spec', 'frame_of_reference', 'vmag',
         'wave_velocity_spec', 'avg_flow_velocity', 'ocw_ship_vel_spec',
         'ocw_ship_vmag', 'moving_object_direction', 'ocw_sp_vel_spec',
         'ocw_sp_vmag', 'secondary_phase_direction', 'ocw_pp_vel_spec',
         'ocw_pp_ref_ht', 'ocw_pp_power_coeff', 'ocw_pp_vmag',
         'ocw_pp_vmag_ref', 'primary_phase_direction',
         'initial_gauge_pressure', 'coordinate_system', 'velocity',
         'flow_direction', 'axis_direction', 'axis_origin', 'omega_swirl',
         'phase_spec', 'wave_bc_type', 'ht_local', 'ht_bottom',
         'wave_dir_spec', 'reference_direction', 'wave_modeling_type',
         'wave_list', 'wave_list_shallow', 'wave_spect_method_freq',
         'wave_spect_factor', 'wave_spect_sig_wave_ht',
         'wave_spect_peak_freq', 'wave_spect_min_freq', 'wave_spect_max_freq',
         'wave_spect_freq_components', 'wave_spect_method_dir',
         'wave_spect_s', 'wave_spect_mean_angle', 'wave_spect_deviation',
         'wave_spect_dir_components', 't', 'non_equil_boundary', 'tve',
         'les_spec_name', 'rfg_number_of_modes', 'vm_number_of_vortices',
         'vm_streamwise_fluct', 'vm_mass_conservation',
         'stg_scale_limiter_type', 'stg_ti_limiter', 'stg_tvr_limiter',
         'stg_dw_limiter', 'volumetric_synthetic_turbulence_generator',
         'volumetric_synthetic_turbulence_generator_option',
         'volumetric_synthetic_turbulence_generator_option_thickness',
         'ke_spec', 'nut', 'kl', 'intermit', 'k', 'e', 'o', 'v2',
         'turb_intensity', 'turb_length_scale', 'turb_hydraulic_diam',
         'turb_viscosity_ratio', 'turb_viscosity_ratio_profile', 'rst_spec',
         'uu', 'vv', 'ww', 'uv', 'vw', 'uw', 'ksgs_spec', 'ksgs',
         'sgs_turb_intensity', 'granular_temperature', 'iac', 'lsfun',
         'volume_fraction', 'species_in_mole_fractions', 'mf',
         'elec_potential_type', 'potential_value', 'dual_potential_type',
         'dual_potential_value', 'x_displacement_type',
         'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'prob_mode_1', 'prob_mode_2', 'prob_mode_3',
         'equ_required', 'uds_bc', 'uds', 'pb_disc_bc', 'pb_disc',
         'pb_qmom_bc', 'pb_qmom', 'pb_smm_bc', 'pb_smm', 'pb_dqmom_bc',
         'pb_dqmom', 'gauge_pressure', 'premixc', 'premixc_var', 'ecfm_sigma',
         'inert', 'pollut_no', 'pollut_hcn', 'pollut_nh3', 'pollut_n2o',
         'pollut_urea', 'pollut_hnco', 'pollut_nco', 'pollut_so2',
         'pollut_h2s', 'pollut_so3', 'pollut_sh', 'pollut_so', 'pollut_soot',
         'pollut_nuclei', 'pollut_ctar', 'pollut_hg', 'pollut_hgcl2',
         'pollut_hcl', 'pollut_hgo', 'pollut_cl', 'pollut_cl2', 'pollut_hgcl',
         'pollut_hocl', 'radiation_bc', 'radial_direction', 'coll_dtheta',
         'coll_dphi', 'band_q_irrad', 'band_q_irrad_diffuse',
         'parallel_collimated_beam', 'solar_direction', 'solar_irradiation',
         't_b_b_spec', 't_b_b', 'in_emiss', 'fmean', 'fvar', 'fmean2',
         'fvar2', 'tss_scalar', 'dpm_bc_type', 'dpm_bc_collision_partner',
         'reinj_inj', 'dpm_bc_udf', 'fensapice_flow_bc_subtype',
         'fensapice_drop_bccustom', 'fensapice_drop_lwc',
         'fensapice_drop_dtemp', 'fensapice_drop_ddiam', 'fensapice_drop_dv',
         'fensapice_drop_dx', 'fensapice_drop_dy', 'fensapice_drop_dz',
         'fensapice_dpm_surface_injection', 'fensapice_dpm_inj_nstream',
         'fensapice_drop_icc', 'fensapice_drop_ctemp', 'fensapice_drop_cdiam',
         'fensapice_drop_cv', 'fensapice_drop_cx', 'fensapice_drop_cy',
         'fensapice_drop_cz', 'fensapice_drop_vrh', 'fensapice_drop_vrh_1',
         'fensapice_drop_vc', 'mixing_plane_thread', 'solar_fluxes',
         'solar_shining_factor', 'radiating_s2s_surface', 'ac_options',
         'impedance_0', 'impedance_1', 'impedance_2', 'ac_wave', 'les_spec']

    phase: phase = phase
    """
    phase child of velocity_inlet_child.
    """
    geom_disable: geom_disable = geom_disable
    """
    geom_disable child of velocity_inlet_child.
    """
    geom_dir_spec: geom_dir_spec = geom_dir_spec
    """
    geom_dir_spec child of velocity_inlet_child.
    """
    geom_dir_x: geom_dir_x = geom_dir_x
    """
    geom_dir_x child of velocity_inlet_child.
    """
    geom_dir_y: geom_dir_y = geom_dir_y
    """
    geom_dir_y child of velocity_inlet_child.
    """
    geom_dir_z: geom_dir_z = geom_dir_z
    """
    geom_dir_z child of velocity_inlet_child.
    """
    geom_levels: geom_levels = geom_levels
    """
    geom_levels child of velocity_inlet_child.
    """
    geom_bgthread: geom_bgthread = geom_bgthread
    """
    geom_bgthread child of velocity_inlet_child.
    """
    open_channel_wave_bc: open_channel_wave_bc = open_channel_wave_bc
    """
    open_channel_wave_bc child of velocity_inlet_child.
    """
    ocw_vel_segregated: ocw_vel_segregated = ocw_vel_segregated
    """
    ocw_vel_segregated child of velocity_inlet_child.
    """
    velocity_spec: velocity_spec = velocity_spec
    """
    velocity_spec child of velocity_inlet_child.
    """
    frame_of_reference: frame_of_reference = frame_of_reference
    """
    frame_of_reference child of velocity_inlet_child.
    """
    vmag: vmag = vmag
    """
    vmag child of velocity_inlet_child.
    """
    wave_velocity_spec: wave_velocity_spec = wave_velocity_spec
    """
    wave_velocity_spec child of velocity_inlet_child.
    """
    avg_flow_velocity: avg_flow_velocity = avg_flow_velocity
    """
    avg_flow_velocity child of velocity_inlet_child.
    """
    ocw_ship_vel_spec: ocw_ship_vel_spec = ocw_ship_vel_spec
    """
    ocw_ship_vel_spec child of velocity_inlet_child.
    """
    ocw_ship_vmag: ocw_ship_vmag = ocw_ship_vmag
    """
    ocw_ship_vmag child of velocity_inlet_child.
    """
    moving_object_direction: moving_object_direction = moving_object_direction
    """
    moving_object_direction child of velocity_inlet_child.
    """
    ocw_sp_vel_spec: ocw_sp_vel_spec = ocw_sp_vel_spec
    """
    ocw_sp_vel_spec child of velocity_inlet_child.
    """
    ocw_sp_vmag: ocw_sp_vmag = ocw_sp_vmag
    """
    ocw_sp_vmag child of velocity_inlet_child.
    """
    secondary_phase_direction: secondary_phase_direction = secondary_phase_direction
    """
    secondary_phase_direction child of velocity_inlet_child.
    """
    ocw_pp_vel_spec: ocw_pp_vel_spec = ocw_pp_vel_spec
    """
    ocw_pp_vel_spec child of velocity_inlet_child.
    """
    ocw_pp_ref_ht: ocw_pp_ref_ht = ocw_pp_ref_ht
    """
    ocw_pp_ref_ht child of velocity_inlet_child.
    """
    ocw_pp_power_coeff: ocw_pp_power_coeff = ocw_pp_power_coeff
    """
    ocw_pp_power_coeff child of velocity_inlet_child.
    """
    ocw_pp_vmag: ocw_pp_vmag = ocw_pp_vmag
    """
    ocw_pp_vmag child of velocity_inlet_child.
    """
    ocw_pp_vmag_ref: ocw_pp_vmag_ref = ocw_pp_vmag_ref
    """
    ocw_pp_vmag_ref child of velocity_inlet_child.
    """
    primary_phase_direction: primary_phase_direction = primary_phase_direction
    """
    primary_phase_direction child of velocity_inlet_child.
    """
    initial_gauge_pressure: initial_gauge_pressure = initial_gauge_pressure
    """
    initial_gauge_pressure child of velocity_inlet_child.
    """
    coordinate_system: coordinate_system = coordinate_system
    """
    coordinate_system child of velocity_inlet_child.
    """
    velocity: velocity = velocity
    """
    velocity child of velocity_inlet_child.
    """
    flow_direction: flow_direction = flow_direction
    """
    flow_direction child of velocity_inlet_child.
    """
    axis_direction: axis_direction = axis_direction
    """
    axis_direction child of velocity_inlet_child.
    """
    axis_origin: axis_origin = axis_origin
    """
    axis_origin child of velocity_inlet_child.
    """
    omega_swirl: omega_swirl = omega_swirl
    """
    omega_swirl child of velocity_inlet_child.
    """
    phase_spec: phase_spec = phase_spec
    """
    phase_spec child of velocity_inlet_child.
    """
    wave_bc_type: wave_bc_type = wave_bc_type
    """
    wave_bc_type child of velocity_inlet_child.
    """
    ht_local: ht_local = ht_local
    """
    ht_local child of velocity_inlet_child.
    """
    ht_bottom: ht_bottom = ht_bottom
    """
    ht_bottom child of velocity_inlet_child.
    """
    wave_dir_spec: wave_dir_spec = wave_dir_spec
    """
    wave_dir_spec child of velocity_inlet_child.
    """
    reference_direction: reference_direction = reference_direction
    """
    reference_direction child of velocity_inlet_child.
    """
    wave_modeling_type: wave_modeling_type = wave_modeling_type
    """
    wave_modeling_type child of velocity_inlet_child.
    """
    wave_list: wave_list = wave_list
    """
    wave_list child of velocity_inlet_child.
    """
    wave_list_shallow: wave_list_shallow = wave_list_shallow
    """
    wave_list_shallow child of velocity_inlet_child.
    """
    wave_spect_method_freq: wave_spect_method_freq = wave_spect_method_freq
    """
    wave_spect_method_freq child of velocity_inlet_child.
    """
    wave_spect_factor: wave_spect_factor = wave_spect_factor
    """
    wave_spect_factor child of velocity_inlet_child.
    """
    wave_spect_sig_wave_ht: wave_spect_sig_wave_ht = wave_spect_sig_wave_ht
    """
    wave_spect_sig_wave_ht child of velocity_inlet_child.
    """
    wave_spect_peak_freq: wave_spect_peak_freq = wave_spect_peak_freq
    """
    wave_spect_peak_freq child of velocity_inlet_child.
    """
    wave_spect_min_freq: wave_spect_min_freq = wave_spect_min_freq
    """
    wave_spect_min_freq child of velocity_inlet_child.
    """
    wave_spect_max_freq: wave_spect_max_freq = wave_spect_max_freq
    """
    wave_spect_max_freq child of velocity_inlet_child.
    """
    wave_spect_freq_components: wave_spect_freq_components = wave_spect_freq_components
    """
    wave_spect_freq_components child of velocity_inlet_child.
    """
    wave_spect_method_dir: wave_spect_method_dir = wave_spect_method_dir
    """
    wave_spect_method_dir child of velocity_inlet_child.
    """
    wave_spect_s: wave_spect_s = wave_spect_s
    """
    wave_spect_s child of velocity_inlet_child.
    """
    wave_spect_mean_angle: wave_spect_mean_angle = wave_spect_mean_angle
    """
    wave_spect_mean_angle child of velocity_inlet_child.
    """
    wave_spect_deviation: wave_spect_deviation = wave_spect_deviation
    """
    wave_spect_deviation child of velocity_inlet_child.
    """
    wave_spect_dir_components: wave_spect_dir_components = wave_spect_dir_components
    """
    wave_spect_dir_components child of velocity_inlet_child.
    """
    t: t = t
    """
    t child of velocity_inlet_child.
    """
    non_equil_boundary: non_equil_boundary = non_equil_boundary
    """
    non_equil_boundary child of velocity_inlet_child.
    """
    tve: tve = tve
    """
    tve child of velocity_inlet_child.
    """
    les_spec_name: les_spec_name = les_spec_name
    """
    les_spec_name child of velocity_inlet_child.
    """
    rfg_number_of_modes: rfg_number_of_modes = rfg_number_of_modes
    """
    rfg_number_of_modes child of velocity_inlet_child.
    """
    vm_number_of_vortices: vm_number_of_vortices = vm_number_of_vortices
    """
    vm_number_of_vortices child of velocity_inlet_child.
    """
    vm_streamwise_fluct: vm_streamwise_fluct = vm_streamwise_fluct
    """
    vm_streamwise_fluct child of velocity_inlet_child.
    """
    vm_mass_conservation: vm_mass_conservation = vm_mass_conservation
    """
    vm_mass_conservation child of velocity_inlet_child.
    """
    stg_scale_limiter_type: stg_scale_limiter_type = stg_scale_limiter_type
    """
    stg_scale_limiter_type child of velocity_inlet_child.
    """
    stg_ti_limiter: stg_ti_limiter = stg_ti_limiter
    """
    stg_ti_limiter child of velocity_inlet_child.
    """
    stg_tvr_limiter: stg_tvr_limiter = stg_tvr_limiter
    """
    stg_tvr_limiter child of velocity_inlet_child.
    """
    stg_dw_limiter: stg_dw_limiter = stg_dw_limiter
    """
    stg_dw_limiter child of velocity_inlet_child.
    """
    volumetric_synthetic_turbulence_generator: volumetric_synthetic_turbulence_generator = volumetric_synthetic_turbulence_generator
    """
    volumetric_synthetic_turbulence_generator child of velocity_inlet_child.
    """
    volumetric_synthetic_turbulence_generator_option: volumetric_synthetic_turbulence_generator_option = volumetric_synthetic_turbulence_generator_option
    """
    volumetric_synthetic_turbulence_generator_option child of velocity_inlet_child.
    """
    volumetric_synthetic_turbulence_generator_option_thickness: volumetric_synthetic_turbulence_generator_option_thickness = volumetric_synthetic_turbulence_generator_option_thickness
    """
    volumetric_synthetic_turbulence_generator_option_thickness child of velocity_inlet_child.
    """
    ke_spec: ke_spec = ke_spec
    """
    ke_spec child of velocity_inlet_child.
    """
    nut: nut = nut
    """
    nut child of velocity_inlet_child.
    """
    kl: kl = kl
    """
    kl child of velocity_inlet_child.
    """
    intermit: intermit = intermit
    """
    intermit child of velocity_inlet_child.
    """
    k: k = k
    """
    k child of velocity_inlet_child.
    """
    e: e = e
    """
    e child of velocity_inlet_child.
    """
    o: o = o
    """
    o child of velocity_inlet_child.
    """
    v2: v2 = v2
    """
    v2 child of velocity_inlet_child.
    """
    turb_intensity: turb_intensity = turb_intensity
    """
    turb_intensity child of velocity_inlet_child.
    """
    turb_length_scale: turb_length_scale = turb_length_scale
    """
    turb_length_scale child of velocity_inlet_child.
    """
    turb_hydraulic_diam: turb_hydraulic_diam = turb_hydraulic_diam
    """
    turb_hydraulic_diam child of velocity_inlet_child.
    """
    turb_viscosity_ratio: turb_viscosity_ratio = turb_viscosity_ratio
    """
    turb_viscosity_ratio child of velocity_inlet_child.
    """
    turb_viscosity_ratio_profile: turb_viscosity_ratio_profile = turb_viscosity_ratio_profile
    """
    turb_viscosity_ratio_profile child of velocity_inlet_child.
    """
    rst_spec: rst_spec = rst_spec
    """
    rst_spec child of velocity_inlet_child.
    """
    uu: uu = uu
    """
    uu child of velocity_inlet_child.
    """
    vv: vv = vv
    """
    vv child of velocity_inlet_child.
    """
    ww: ww = ww
    """
    ww child of velocity_inlet_child.
    """
    uv: uv = uv
    """
    uv child of velocity_inlet_child.
    """
    vw: vw = vw
    """
    vw child of velocity_inlet_child.
    """
    uw: uw = uw
    """
    uw child of velocity_inlet_child.
    """
    ksgs_spec: ksgs_spec = ksgs_spec
    """
    ksgs_spec child of velocity_inlet_child.
    """
    ksgs: ksgs = ksgs
    """
    ksgs child of velocity_inlet_child.
    """
    sgs_turb_intensity: sgs_turb_intensity = sgs_turb_intensity
    """
    sgs_turb_intensity child of velocity_inlet_child.
    """
    granular_temperature: granular_temperature = granular_temperature
    """
    granular_temperature child of velocity_inlet_child.
    """
    iac: iac = iac
    """
    iac child of velocity_inlet_child.
    """
    lsfun: lsfun = lsfun
    """
    lsfun child of velocity_inlet_child.
    """
    volume_fraction: volume_fraction = volume_fraction
    """
    volume_fraction child of velocity_inlet_child.
    """
    species_in_mole_fractions: species_in_mole_fractions = species_in_mole_fractions
    """
    species_in_mole_fractions child of velocity_inlet_child.
    """
    mf: mf = mf
    """
    mf child of velocity_inlet_child.
    """
    elec_potential_type: elec_potential_type = elec_potential_type
    """
    elec_potential_type child of velocity_inlet_child.
    """
    potential_value: potential_value = potential_value
    """
    potential_value child of velocity_inlet_child.
    """
    dual_potential_type: dual_potential_type = dual_potential_type
    """
    dual_potential_type child of velocity_inlet_child.
    """
    dual_potential_value: dual_potential_value = dual_potential_value
    """
    dual_potential_value child of velocity_inlet_child.
    """
    x_displacement_type: x_displacement_type = x_displacement_type
    """
    x_displacement_type child of velocity_inlet_child.
    """
    x_displacement_value: x_displacement_value = x_displacement_value
    """
    x_displacement_value child of velocity_inlet_child.
    """
    y_displacement_type: y_displacement_type = y_displacement_type
    """
    y_displacement_type child of velocity_inlet_child.
    """
    y_displacement_value: y_displacement_value = y_displacement_value
    """
    y_displacement_value child of velocity_inlet_child.
    """
    z_displacement_type: z_displacement_type = z_displacement_type
    """
    z_displacement_type child of velocity_inlet_child.
    """
    z_displacement_value: z_displacement_value = z_displacement_value
    """
    z_displacement_value child of velocity_inlet_child.
    """
    prob_mode_1: prob_mode_1 = prob_mode_1
    """
    prob_mode_1 child of velocity_inlet_child.
    """
    prob_mode_2: prob_mode_2 = prob_mode_2
    """
    prob_mode_2 child of velocity_inlet_child.
    """
    prob_mode_3: prob_mode_3 = prob_mode_3
    """
    prob_mode_3 child of velocity_inlet_child.
    """
    equ_required: equ_required = equ_required
    """
    equ_required child of velocity_inlet_child.
    """
    uds_bc: uds_bc = uds_bc
    """
    uds_bc child of velocity_inlet_child.
    """
    uds: uds = uds
    """
    uds child of velocity_inlet_child.
    """
    pb_disc_bc: pb_disc_bc = pb_disc_bc
    """
    pb_disc_bc child of velocity_inlet_child.
    """
    pb_disc: pb_disc = pb_disc
    """
    pb_disc child of velocity_inlet_child.
    """
    pb_qmom_bc: pb_qmom_bc = pb_qmom_bc
    """
    pb_qmom_bc child of velocity_inlet_child.
    """
    pb_qmom: pb_qmom = pb_qmom
    """
    pb_qmom child of velocity_inlet_child.
    """
    pb_smm_bc: pb_smm_bc = pb_smm_bc
    """
    pb_smm_bc child of velocity_inlet_child.
    """
    pb_smm: pb_smm = pb_smm
    """
    pb_smm child of velocity_inlet_child.
    """
    pb_dqmom_bc: pb_dqmom_bc = pb_dqmom_bc
    """
    pb_dqmom_bc child of velocity_inlet_child.
    """
    pb_dqmom: pb_dqmom = pb_dqmom
    """
    pb_dqmom child of velocity_inlet_child.
    """
    gauge_pressure: gauge_pressure = gauge_pressure
    """
    gauge_pressure child of velocity_inlet_child.
    """
    premixc: premixc = premixc
    """
    premixc child of velocity_inlet_child.
    """
    premixc_var: premixc_var = premixc_var
    """
    premixc_var child of velocity_inlet_child.
    """
    ecfm_sigma: ecfm_sigma = ecfm_sigma
    """
    ecfm_sigma child of velocity_inlet_child.
    """
    inert: inert = inert
    """
    inert child of velocity_inlet_child.
    """
    pollut_no: pollut_no = pollut_no
    """
    pollut_no child of velocity_inlet_child.
    """
    pollut_hcn: pollut_hcn = pollut_hcn
    """
    pollut_hcn child of velocity_inlet_child.
    """
    pollut_nh3: pollut_nh3 = pollut_nh3
    """
    pollut_nh3 child of velocity_inlet_child.
    """
    pollut_n2o: pollut_n2o = pollut_n2o
    """
    pollut_n2o child of velocity_inlet_child.
    """
    pollut_urea: pollut_urea = pollut_urea
    """
    pollut_urea child of velocity_inlet_child.
    """
    pollut_hnco: pollut_hnco = pollut_hnco
    """
    pollut_hnco child of velocity_inlet_child.
    """
    pollut_nco: pollut_nco = pollut_nco
    """
    pollut_nco child of velocity_inlet_child.
    """
    pollut_so2: pollut_so2 = pollut_so2
    """
    pollut_so2 child of velocity_inlet_child.
    """
    pollut_h2s: pollut_h2s = pollut_h2s
    """
    pollut_h2s child of velocity_inlet_child.
    """
    pollut_so3: pollut_so3 = pollut_so3
    """
    pollut_so3 child of velocity_inlet_child.
    """
    pollut_sh: pollut_sh = pollut_sh
    """
    pollut_sh child of velocity_inlet_child.
    """
    pollut_so: pollut_so = pollut_so
    """
    pollut_so child of velocity_inlet_child.
    """
    pollut_soot: pollut_soot = pollut_soot
    """
    pollut_soot child of velocity_inlet_child.
    """
    pollut_nuclei: pollut_nuclei = pollut_nuclei
    """
    pollut_nuclei child of velocity_inlet_child.
    """
    pollut_ctar: pollut_ctar = pollut_ctar
    """
    pollut_ctar child of velocity_inlet_child.
    """
    pollut_hg: pollut_hg = pollut_hg
    """
    pollut_hg child of velocity_inlet_child.
    """
    pollut_hgcl2: pollut_hgcl2 = pollut_hgcl2
    """
    pollut_hgcl2 child of velocity_inlet_child.
    """
    pollut_hcl: pollut_hcl = pollut_hcl
    """
    pollut_hcl child of velocity_inlet_child.
    """
    pollut_hgo: pollut_hgo = pollut_hgo
    """
    pollut_hgo child of velocity_inlet_child.
    """
    pollut_cl: pollut_cl = pollut_cl
    """
    pollut_cl child of velocity_inlet_child.
    """
    pollut_cl2: pollut_cl2 = pollut_cl2
    """
    pollut_cl2 child of velocity_inlet_child.
    """
    pollut_hgcl: pollut_hgcl = pollut_hgcl
    """
    pollut_hgcl child of velocity_inlet_child.
    """
    pollut_hocl: pollut_hocl = pollut_hocl
    """
    pollut_hocl child of velocity_inlet_child.
    """
    radiation_bc: radiation_bc = radiation_bc
    """
    radiation_bc child of velocity_inlet_child.
    """
    radial_direction: radial_direction = radial_direction
    """
    radial_direction child of velocity_inlet_child.
    """
    coll_dtheta: coll_dtheta = coll_dtheta
    """
    coll_dtheta child of velocity_inlet_child.
    """
    coll_dphi: coll_dphi = coll_dphi
    """
    coll_dphi child of velocity_inlet_child.
    """
    band_q_irrad: band_q_irrad = band_q_irrad
    """
    band_q_irrad child of velocity_inlet_child.
    """
    band_q_irrad_diffuse: band_q_irrad_diffuse = band_q_irrad_diffuse
    """
    band_q_irrad_diffuse child of velocity_inlet_child.
    """
    parallel_collimated_beam: parallel_collimated_beam = parallel_collimated_beam
    """
    parallel_collimated_beam child of velocity_inlet_child.
    """
    solar_direction: solar_direction = solar_direction
    """
    solar_direction child of velocity_inlet_child.
    """
    solar_irradiation: solar_irradiation = solar_irradiation
    """
    solar_irradiation child of velocity_inlet_child.
    """
    t_b_b_spec: t_b_b_spec = t_b_b_spec
    """
    t_b_b_spec child of velocity_inlet_child.
    """
    t_b_b: t_b_b = t_b_b
    """
    t_b_b child of velocity_inlet_child.
    """
    in_emiss: in_emiss = in_emiss
    """
    in_emiss child of velocity_inlet_child.
    """
    fmean: fmean = fmean
    """
    fmean child of velocity_inlet_child.
    """
    fvar: fvar = fvar
    """
    fvar child of velocity_inlet_child.
    """
    fmean2: fmean2 = fmean2
    """
    fmean2 child of velocity_inlet_child.
    """
    fvar2: fvar2 = fvar2
    """
    fvar2 child of velocity_inlet_child.
    """
    tss_scalar: tss_scalar = tss_scalar
    """
    tss_scalar child of velocity_inlet_child.
    """
    dpm_bc_type: dpm_bc_type = dpm_bc_type
    """
    dpm_bc_type child of velocity_inlet_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner = dpm_bc_collision_partner
    """
    dpm_bc_collision_partner child of velocity_inlet_child.
    """
    reinj_inj: reinj_inj = reinj_inj
    """
    reinj_inj child of velocity_inlet_child.
    """
    dpm_bc_udf: dpm_bc_udf = dpm_bc_udf
    """
    dpm_bc_udf child of velocity_inlet_child.
    """
    fensapice_flow_bc_subtype: fensapice_flow_bc_subtype = fensapice_flow_bc_subtype
    """
    fensapice_flow_bc_subtype child of velocity_inlet_child.
    """
    fensapice_drop_bccustom: fensapice_drop_bccustom = fensapice_drop_bccustom
    """
    fensapice_drop_bccustom child of velocity_inlet_child.
    """
    fensapice_drop_lwc: fensapice_drop_lwc = fensapice_drop_lwc
    """
    fensapice_drop_lwc child of velocity_inlet_child.
    """
    fensapice_drop_dtemp: fensapice_drop_dtemp = fensapice_drop_dtemp
    """
    fensapice_drop_dtemp child of velocity_inlet_child.
    """
    fensapice_drop_ddiam: fensapice_drop_ddiam = fensapice_drop_ddiam
    """
    fensapice_drop_ddiam child of velocity_inlet_child.
    """
    fensapice_drop_dv: fensapice_drop_dv = fensapice_drop_dv
    """
    fensapice_drop_dv child of velocity_inlet_child.
    """
    fensapice_drop_dx: fensapice_drop_dx = fensapice_drop_dx
    """
    fensapice_drop_dx child of velocity_inlet_child.
    """
    fensapice_drop_dy: fensapice_drop_dy = fensapice_drop_dy
    """
    fensapice_drop_dy child of velocity_inlet_child.
    """
    fensapice_drop_dz: fensapice_drop_dz = fensapice_drop_dz
    """
    fensapice_drop_dz child of velocity_inlet_child.
    """
    fensapice_dpm_surface_injection: fensapice_dpm_surface_injection = fensapice_dpm_surface_injection
    """
    fensapice_dpm_surface_injection child of velocity_inlet_child.
    """
    fensapice_dpm_inj_nstream: fensapice_dpm_inj_nstream = fensapice_dpm_inj_nstream
    """
    fensapice_dpm_inj_nstream child of velocity_inlet_child.
    """
    fensapice_drop_icc: fensapice_drop_icc = fensapice_drop_icc
    """
    fensapice_drop_icc child of velocity_inlet_child.
    """
    fensapice_drop_ctemp: fensapice_drop_ctemp = fensapice_drop_ctemp
    """
    fensapice_drop_ctemp child of velocity_inlet_child.
    """
    fensapice_drop_cdiam: fensapice_drop_cdiam = fensapice_drop_cdiam
    """
    fensapice_drop_cdiam child of velocity_inlet_child.
    """
    fensapice_drop_cv: fensapice_drop_cv = fensapice_drop_cv
    """
    fensapice_drop_cv child of velocity_inlet_child.
    """
    fensapice_drop_cx: fensapice_drop_cx = fensapice_drop_cx
    """
    fensapice_drop_cx child of velocity_inlet_child.
    """
    fensapice_drop_cy: fensapice_drop_cy = fensapice_drop_cy
    """
    fensapice_drop_cy child of velocity_inlet_child.
    """
    fensapice_drop_cz: fensapice_drop_cz = fensapice_drop_cz
    """
    fensapice_drop_cz child of velocity_inlet_child.
    """
    fensapice_drop_vrh: fensapice_drop_vrh = fensapice_drop_vrh
    """
    fensapice_drop_vrh child of velocity_inlet_child.
    """
    fensapice_drop_vrh_1: fensapice_drop_vrh_1 = fensapice_drop_vrh_1
    """
    fensapice_drop_vrh_1 child of velocity_inlet_child.
    """
    fensapice_drop_vc: fensapice_drop_vc = fensapice_drop_vc
    """
    fensapice_drop_vc child of velocity_inlet_child.
    """
    mixing_plane_thread: mixing_plane_thread = mixing_plane_thread
    """
    mixing_plane_thread child of velocity_inlet_child.
    """
    solar_fluxes: solar_fluxes = solar_fluxes
    """
    solar_fluxes child of velocity_inlet_child.
    """
    solar_shining_factor: solar_shining_factor = solar_shining_factor
    """
    solar_shining_factor child of velocity_inlet_child.
    """
    radiating_s2s_surface: radiating_s2s_surface = radiating_s2s_surface
    """
    radiating_s2s_surface child of velocity_inlet_child.
    """
    ac_options: ac_options = ac_options
    """
    ac_options child of velocity_inlet_child.
    """
    impedance_0: impedance_0 = impedance_0
    """
    impedance_0 child of velocity_inlet_child.
    """
    impedance_1: impedance_1 = impedance_1
    """
    impedance_1 child of velocity_inlet_child.
    """
    impedance_2: impedance_2 = impedance_2
    """
    impedance_2 child of velocity_inlet_child.
    """
    ac_wave: ac_wave = ac_wave
    """
    ac_wave child of velocity_inlet_child.
    """
    les_spec: les_spec = les_spec
    """
    les_spec child of velocity_inlet_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_7 import option
from .virtual_mass_factor import virtual_mass_factor
class virtual_mass_force(Group):
    """
    'virtual_mass_force' child.
    """

    fluent_name = "virtual-mass-force"

    child_names = \
        ['option', 'virtual_mass_factor']

    option: option = option
    """
    option child of virtual_mass_force.
    """
    virtual_mass_factor: virtual_mass_factor = virtual_mass_factor
    """
    virtual_mass_factor child of virtual_mass_force.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .width import width
from .height import height
class field(Command):
    """
    Set the field of view (width and height).
    
    Parameters
    ----------
        width : real
            'width' child.
        height : real
            'height' child.
    
    """

    fluent_name = "field"

    argument_names = \
        ['width', 'height']

    width: width = width
    """
    width argument of field.
    """
    height: height = height
    """
    height argument of field.
    """
